@@ -4,11 +4,11 @@ __author__ = 'chengzhi'
 name = "tqsdk"
 
 from tqsdk.api import TqApi
-from tqsdk.tradeable import TqAccount, TqKq, TqKqStock, TqSim, TqSimStock
+from tqsdk.tradeable import TqAccount, TqZq,  TqKq, TqKqStock, TqSim, TqSimStock, TqCtp, TqRohon, TqJees, TqYida, TqTradingUnit
 from tqsdk.auth import TqAuth
 from tqsdk.channel import TqChan
 from tqsdk.backtest import TqBacktest, TqReplay
-from tqsdk.exceptions import BacktestFinished, TqTimeoutError, TqRiskRuleError
+from tqsdk.exceptions import BacktestFinished, TqBacktestPermissionError, TqTimeoutError, TqRiskRuleError
 from tqsdk.lib import TargetPosScheduler, TargetPosTask, InsertOrderUntilAllTradedTask, InsertOrderTask, TqNotify
 from tqsdk.multiaccount import TqMultiAccount
 from .__version__ import __version__
