@@ -2,15 +2,18 @@
 #  -*- coding: utf-8 -*-
 __author__ = 'mayanqiong'
 
-from datetime import datetime, time, timedelta
+from datetime import time, timedelta
 from typing import Optional, Union
 
 import numpy as np
+import pandas as pd
 from pandas import DataFrame
 
 from tqsdk.api import TqApi
 from tqsdk import utils
-from tqsdk.datetime import _get_trading_timestamp, _get_trade_timestamp, _get_trading_day_from_timestamp
+from tqsdk.datetime import _get_trading_timestamp, _get_trade_timestamp, _get_trading_day_from_timestamp, \
+    _datetime_to_timestamp_nano, _timestamp_nano_to_datetime
+from tqsdk.lib.time_table import TqTimeTable
 from tqsdk.rangeset import _rangeset_slice, _rangeset_head
 from tqsdk.tradeable import TqAccount, TqKq, TqSim
 
@@ -48,7 +51,7 @@ def twap_table(api: TqApi, symbol: str, target_pos: int, duration: int, min_volu
         from tqsdk import TqApi, TargetPosScheduler
         from tqsdk.algorithm import twap_table
 
-        api = TqApi(auth="信易账户,用户密码")
+        api = TqApi(auth="快期账户,用户密码")
         quote = api.get_quote("CZCE.MA109")
 
         # 设置twap任务参数
@@ -67,7 +70,7 @@ def twap_table(api: TqApi, symbol: str, target_pos: int, duration: int, min_volu
         from tqsdk import TqApi, TargetPosScheduler
         from tqsdk.algorithm import twap_table
 
-        api = TqApi(auth="信易账户,用户密码")
+        api = TqApi(auth="快期账户,用户密码")
         quote = api.get_quote("CZCE.MA109")
 
         # 设置 twap 任务参数，
@@ -122,14 +125,15 @@ def twap_table(api: TqApi, symbol: str, target_pos: int, duration: int, min_volu
         interval_list = _gen_random_list(sum_val=duration, min_val=min_interval, max_val=max_interval,
                                          length=len(volume_list))
 
-    time_table = DataFrame(columns=['interval', 'volume', 'price'])
+    time_table = TqTimeTable(account=account)
     for index, volume in enumerate(volume_list):
         assert interval_list[index] >= 3
         active_interval = 2
-        time_table = time_table.append([
+        append_time_table = pd.DataFrame([
             {"interval": interval_list[index] - active_interval, "volume": volume, "price": "PASSIVE"},
             {"interval": active_interval, "volume": 0, "price": "ACTIVE"}
-        ], ignore_index=True)
+        ])
+        time_table = pd.concat([time_table, append_time_table], ignore_index=True)
     time_table['volume'] = time_table['volume'].mul(-1 if delta_pos < 0 else 1)
     time_table['target_pos'] = time_table['volume'].cumsum()
     time_table['target_pos'] = time_table['target_pos'].add(pos.pos)
@@ -177,7 +181,7 @@ def vwap_table(api: TqApi, symbol: str, target_pos: int, duration: float,
         from tqsdk import TqApi, TargetPosScheduler
         from tqsdk.algorithm import vwap_table
 
-        api = TqApi(auth="信易账户,用户密码")
+        api = TqApi(auth="快期账户,用户密码")
         quote = api.get_quote("CZCE.MA109")
 
         # 设置 vwap 任务参数
@@ -202,7 +206,7 @@ def vwap_table(api: TqApi, symbol: str, target_pos: int, duration: float,
     if duration % TIME_CELL or duration < 60:
         raise Exception(f"duration {duration} 参数应该为 {TIME_CELL} 的整数倍")
 
-    pos = api.get_position(symbol, account)
+    pos = account.get_position(symbol)
     target_pos = int(target_pos)
     delta_pos = target_pos - pos.pos
     target_volume = abs(delta_pos)  # 总的下单手数
@@ -211,8 +215,8 @@ def vwap_table(api: TqApi, symbol: str, target_pos: int, duration: float,
 
     # 获取 Kline
     klines = api.get_kline_serial(symbol, TIME_CELL, data_length=int(10 * 60 * 60 / TIME_CELL * HISTORY_DAY_LENGTH))
-    klines["time"] = klines.datetime.apply(lambda x: datetime.fromtimestamp(x // 1000000000).time())  # k线时间
-    klines["date"] = klines.datetime.apply(lambda x: datetime.fromtimestamp(_get_trading_day_from_timestamp(x) // 1000000000).date())  # k线交易日
+    klines["time"] = klines.datetime.apply(lambda x: _timestamp_nano_to_datetime(x).time())  # k线时间
+    klines["date"] = klines.datetime.apply(lambda x: _timestamp_nano_to_datetime(_get_trading_day_from_timestamp(x)).date())  # k线交易日
 
     quote = api.get_quote(symbol)
     # 当前交易日完整的交易时间段
@@ -223,16 +227,16 @@ def vwap_table(api: TqApi, symbol: str, target_pos: int, duration: float,
     if not trading_timestamp_nano_range[0][0] <= current_timestamp_nano < trading_timestamp_nano_range[-1][1]:
         raise Exception("当前时间不在指定的交易时间段内")
 
-    current_datetime = datetime.fromtimestamp(current_timestamp_nano//1000000000)
+    current_datetime = _timestamp_nano_to_datetime(current_timestamp_nano)
     # 下一分钟的开始时间
     next_datetime = current_datetime.replace(second=0) + timedelta(minutes=1)
-    start_datetime_nano = int(next_datetime.timestamp()) * 1000000000
+    start_datetime_nano = _datetime_to_timestamp_nano(next_datetime)
     r = _rangeset_head(_rangeset_slice(trading_timestamp_nano_range, start_datetime_nano), int(duration * 1e9))
     if not (r and trading_timestamp_nano_range[0][0] <= r[-1][-1] < trading_timestamp_nano_range[-1][1]):
         raise Exception("指定时间段超出当前交易日")
 
-    start_datetime = datetime.fromtimestamp(start_datetime_nano // 1000000000)
-    end_datetime = datetime.fromtimestamp((r[-1][-1] - 1) // 1000000000)
+    start_datetime = _timestamp_nano_to_datetime(start_datetime_nano)
+    end_datetime = _timestamp_nano_to_datetime((r[-1][-1] - 1))
     time_slot_start = time(start_datetime.hour, start_datetime.minute)  # 计划交易时段起始时间点
     time_slot_end = time(end_datetime.hour, end_datetime.minute)  # 计划交易时段终点时间点
     if time_slot_end > time_slot_start:  # 判断是否类似 23:00:00 开始， 01:00:00 结束这样跨天的情况
@@ -250,17 +254,18 @@ def vwap_table(api: TqApi, symbol: str, target_pos: int, duration: float,
     predicted_percent = volume_percent.groupby(level=1).mean()  # 将历史上相同时间单元的成交量占比使用算数平均计算出预测值
 
     # 计算每个时间单元的成交量预测值
-    time_table = DataFrame(columns=['interval', 'volume', 'price'])
+    time_table = TqTimeTable(account=account)
     volume_left = target_volume  # 剩余手数
     percent_left = 1  # 剩余百分比
     for index, value in predicted_percent.items():
-        volume = round(target_volume * (value / percent_left))
+        volume = round(volume_left * (value / percent_left))
         volume_left -= volume
         percent_left -= value
-        time_table = time_table.append([
+        append_time_table = pd.DataFrame([
             {"interval": TIME_CELL - 2, "volume": volume, "price": "PASSIVE"},
             {"interval": 2, "volume": 0, "price": "ACTIVE"}
-        ], ignore_index=True)
+        ])
+        time_table = pd.concat([time_table, append_time_table], ignore_index=True)
 
     time_table['volume'] = time_table['volume'].mul(np.sign(delta_pos))
     time_table['target_pos'] = time_table['volume'].cumsum()
