@@ -79,7 +79,7 @@ class Twap(object):
           from tqsdk import TqApi
           from tqsdk.algorithm import Twap
 
-          api = TqApi(auth="信易账户,用户密码")
+          api = TqApi(auth="快期账户,用户密码")
           # 设置twap任务参数
           target_twap = Twap(api,"SHFE.rb2012","BUY","OPEN",500,300,10,25)
           # 启动循环
@@ -94,7 +94,7 @@ class Twap(object):
           from tqsdk import TqApi
           from tqsdk.algorithm import Twap
 
-          api = TqApi(auth="信易账户,用户密码")
+          api = TqApi(auth="快期账户,用户密码")
           target_twap = Twap(api,"SHFE.rb2012","BUY","OPEN",500,300,10,25)
 
           num_of_trades = 0
@@ -117,8 +117,6 @@ class Twap(object):
           print(target_twap.average_trade_price)
           api.close()
         """
-        if symbol.startswith("CZCE.CJ"):
-            raise Exception("红枣期货不支持创建 targetpostask、twap、vwap 任务，交易所规定该品种最小开仓手数为大于等于 4 手，这些函数还未支持该规则!")
         self._api = api
         self._account = api._account._check_valid(account)
         if self._account is None:
@@ -155,6 +153,12 @@ class Twap(object):
 
     async def _run(self, volume_list, interval_list):
         self._quote = await self._api.get_quote(self._symbol)
+        # 判断最小下单手数是否大于1
+        if self._quote.open_min_market_order_volume > 1 or self._quote.open_min_limit_order_volume > 1:
+            raise Exception(
+                f"交易所规定 {self._symbol} 的最小市价开仓手数 ({self._quote.open_min_market_order_volume})"
+                f" 或最小限价开仓手数 ({self._quote.open_min_limit_order_volume}) 大于 1，targetpostask、twap、vwap 这些函数还未支持该规则!"
+            )
         # 计算得到时间序列，每个时间段快要结束的时间点，此时应该从被动价格切换为主动价格
         deadline_timestamp_list, strict_deadline_timestamp_list = self._get_deadline_timestamp(interval_list)
         for i in range(len(volume_list)):
@@ -214,8 +218,7 @@ class Twap(object):
                         if exit_immediately and volume_left == 0:
                             break
         finally:
-            self._order_task._task.cancel()
-            await asyncio.gather(self._order_task._task, return_exceptions=True)
+            await self._api._cancel_task(self._order_task._task)
             while not trade_chan.empty():
                 v = await trade_chan.recv()
                 volume_left = volume_left - (v if self._direction == "BUY" else -v)
@@ -236,8 +239,7 @@ class Twap(object):
                     break
         finally:
             await trade_chan.close()
-            self._order_task._task.cancel()
-            await asyncio.gather(self._order_task._task, return_exceptions=True)
+            await self._api._cancel_task(self._order_task._task)
 
     def _get_volume_list(self):
         if self._volume < self._max_volume_each_order:
@@ -261,7 +263,7 @@ class Twap(object):
           from tqsdk import TqApi
           from tqsdk.algorithm import Twap
 
-          api = TqApi(auth="信易账户,用户密码")
+          api = TqApi(auth="快期账户,用户密码")
           # 设置twap任务参数
           quote = api.get_quote("SHFE.rb2012")
           target_twap = Twap(api,"SHFE.rb2012","BUY","OPEN",500,300,10,25)
