@@ -7,11 +7,12 @@ __author__ = 'mayanqiong'
 import asyncio
 import math
 from datetime import date, datetime
-from typing import Union, Any
+from typing import Union, Any, List, Dict
 
 from tqsdk.backtest.utils import TqBacktestContinuous, TqBacktestDividend
 from tqsdk.channel import TqChan
-from tqsdk.datetime import _get_trading_day_start_time, _get_trading_day_end_time, _get_trading_day_from_timestamp
+from tqsdk.datetime import _get_trading_day_start_time, _get_trading_day_end_time, _get_trading_day_from_timestamp, \
+    _timestamp_nano_to_str, _convert_user_input_to_nano
 from tqsdk.diff import _merge_diff, _get_obj
 from tqsdk.entity import Entity
 from tqsdk.exceptions import BacktestFinished
@@ -63,27 +64,20 @@ class TqBacktest(object):
 
     def __init__(self, start_dt: Union[date, datetime], end_dt: Union[date, datetime]) -> None:
         """
-        创建天勤回测类
+        创建天勤回测类，起始时间和结束时间都应该是北京时间
 
         Args:
-            start_dt (date/datetime): 回测起始时间, 如果类型为 date 则指的是交易日, 如果为 datetime 则指的是具体时间点
+            start_dt (date/datetime): 回测起始时间
+                * date: 指的是交易日
 
-            end_dt (date/datetime): 回测结束时间, 如果类型为 date 则指的是交易日, 如果为 datetime 则指的是具体时间点
+                * datetime: 指的是具体时间点，如果没有指定时区信息，则默认为北京时间
+
+            end_dt (date/datetime): 回测结束时间
+                * date: 指的是交易日
+
+                * datetime: 指的是具体时间点，如果没有指定时区信息，则默认为北京时间
         """
-        if isinstance(start_dt, datetime):
-            self._start_dt = int(start_dt.timestamp() * 1e9)
-        elif isinstance(start_dt, date):
-            self._start_dt = _get_trading_day_start_time(
-                int(datetime(start_dt.year, start_dt.month, start_dt.day).timestamp()) * 1000000000)
-        else:
-            raise Exception("回测起始时间(start_dt)类型 %s 错误, 请检查 start_dt 数据类型是否填写正确" % (type(start_dt)))
-        if isinstance(end_dt, datetime):
-            self._end_dt = int(end_dt.timestamp() * 1e9)
-        elif isinstance(end_dt, date):
-            self._end_dt = _get_trading_day_end_time(
-                int(datetime(end_dt.year, end_dt.month, end_dt.day).timestamp()) * 1000000000)
-        else:
-            raise Exception("回测结束时间(end_dt)类型 %s 错误, 请检查 end_dt 数据类型是否填写正确" % (type(end_dt)))
+        self._start_dt, self._end_dt = _convert_user_input_to_nano(start_dt, end_dt)
         self._current_dt = self._start_dt
         # 记录当前的交易日 开始时间/结束时间
         self._trading_day = _get_trading_day_from_timestamp(self._current_dt)
@@ -133,12 +127,20 @@ class TqBacktest(object):
         }
         self._sended_to_api = {}  # 已经发给 api 的 rangeset  (symbol, dur)，只记录了 kline
         self._serials = {}  # 所有用户请求的 chart 序列，如果用户订阅行情，默认请求 1 分钟 Kline
+        # key 为 (ins, dur)
+        # value 为 dict，包含以下属性
+        #   timestamp: 当前 serial 最新的时间戳
+        #   diff: 当前 serial 生成的 diff,
+        #   kline_or_tick: 当前 serial 计算行情对应的 kline 或者 tick
+        #   when: 'TICK' 表示由 tick 产生的行情，'OPEN' | 'CLOSE' 是 kline 开盘或者收盘时的行情
+        #   chart_id_set: 记录当前 serial 对应的所有 chart_id
+
         # gc 是会循环 self._serials，来计算用户需要的数据，self._serials 不应该被删除，
         self._generators = {}  # 所有用户请求的 chart 序列相应的 generator 对象，创建时与 self._serials 一一对应，会在一个序列计算到最后一根 kline 时被删除
         self._had_any_generator = False  # 回测过程中是否有过 generator 对象
         self._sim_recv_chan_send_count = 0  # 统计向下游发送的 diff 的次数，每 1w 次执行一次 gc
         self._quotes = {}  # 记录 min_duration 记录某一合约的最小duration； sended_init_quote 是否已经过这个合约的初始行情
-        self._diffs: list[dict[str, Any]] = []
+        self._diffs: List[Dict[str, Any]] = []
         self._is_first_send = True
         md_task = self._api.create_task(self._md_handler())
         try:
@@ -158,6 +160,7 @@ class TqBacktest(object):
                     self._diffs.append({
                         "ins_list": pack["ins_list"]
                     })
+                    await self._ensure_symbols(pack["ins_list"].split(","))
                     for ins in pack["ins_list"].split(","):
                         await self._ensure_quote(ins)
                     await self._send_diff()  # 处理上一次未处理的 peek_message
@@ -167,9 +170,10 @@ class TqBacktest(object):
                         self._diffs.append({
                             "charts": {
                                 pack["chart_id"]: {
-                                    # 两个id设置为0：保证api在回测中判断此值时不是-1，即直接通过对数据接收完全的验证
-                                    "left_id": 0,
-                                    "right_id": 0,
+                                    # 回测中 ready 置为 True，保证api在回测中直接通过对数据接收完全的验证
+                                    "left_id": -1,
+                                    "right_id": -1,
+                                    "ready": True,
                                     "more_data": False,  # 直接发送False给api，表明数据发送完全，使api中通过数据接收完全的验证
                                     "state": pack
                                 }
@@ -190,8 +194,7 @@ class TqBacktest(object):
             # 关闭所有 generator
             for s in self._generators.values():
                 await s.aclose()
-            md_task.cancel()
-            await asyncio.gather(md_task, return_exceptions=True)
+            await self._api._cancel_task(md_task)
 
     async def _md_handler(self):
         async for pack in self._md_recv_chan:
@@ -200,7 +203,7 @@ class TqBacktest(object):
             })
             recv_quotes = False
             for d in pack.get("data", []):
-                _merge_diff(self._data, d, self._prototype, False)
+                _merge_diff(self._data, d, self._prototype, persist=False, reduce_diff=False)
                 # 收到的 quotes 转发给下游
                 quotes = d.get("quotes", {})
                 if quotes:
@@ -230,7 +233,7 @@ class TqBacktest(object):
                 quote.pop("underlying_symbol", None)
             if quote.get('expire_datetime'):
                 # 先删除所有的 quote 的 expired 字段，只在有 expire_datetime 字段时才会添加 expired 字段
-                quote['expired'] = quote.get('expire_datetime') * 1e9 <= self._trading_day_start
+                quote['expired'] = quote.get('expire_datetime') * 1000000000 <= self._trading_day_start
         return quotes
 
     async def _send_snapshot(self):
@@ -267,7 +270,7 @@ class TqBacktest(object):
                     "min_market_order_volume": quote["min_market_order_volume"],
                     "underlying_symbol": quote["underlying_symbol"],
                     "strike_price": quote["strike_price"],
-                    "expired": quote.get('expire_datetime', float('nan')) <= self._trading_day_start,  # expired 默认值就是 False
+                    "expired": quote.get('expire_datetime', float('nan')) * 1000000000 <= self._trading_day_start,  # expired 默认值就是 False
                     "trading_time": {"day": trading_time.get("day", []), "night": trading_time.get("night", [])},
                     "expire_datetime": quote.get("expire_datetime"),
                     "delivery_month": quote.get("delivery_month"),
@@ -290,18 +293,7 @@ class TqBacktest(object):
     async def _send_diff(self):
         """发送数据到 api, 如果 self._diffs 不为空则发送 self._diffs, 不推进行情时间, 否则将时间推进一格, 并发送对应的行情"""
         if self._pending_peek:
-            if not self._diffs:
-                quotes = await self._generator_diffs(False)
-            else:
-                quotes = await self._generator_diffs(True)
-            for ins, diff in quotes.items():
-                self._quotes[ins]["sended_init_quote"] = True
-                for d in diff:
-                    self._diffs.append({
-                        "quotes": {
-                            ins: d
-                        }
-                    })
+            await self._generator_diffs(True if self._diffs else False)
             if self._diffs:
                 # 发送数据集中添加 backtest 字段，开始时间、结束时间、当前时间，表示当前行情推进是由 backtest 推进
                 self._diffs.append({"_tqsdk_backtest": self._get_backtest_time()})
@@ -320,7 +312,7 @@ class TqBacktest(object):
                         "quotes": self._stock_dividend._get_dividend(self._data.get('quotes'), self._trading_day)
                     })
                     self._diffs.append({
-                        "quotes": {k: {'expired': v.get('expire_datetime', float('nan')) <= self._trading_day_start}
+                        "quotes": {k: {'expired': v.get('expire_datetime', float('nan')) * 1000000000 <= self._trading_day_start}
                                    for k, v in self._data.get('quotes').items()}
                     })
 
@@ -341,18 +333,12 @@ class TqBacktest(object):
         keep_current 为 True 表示不会推进行情，为 False 表示需要推进行情
         即 self._diffs 为 None 并且 keep_current = True 会推进行情
         """
-        quotes = {}
+        quotes_helper = {}  # 记录生成行情信息的辅助信息, 用于计算最后返回 quote_diffs
         while self._generators:
             # self._generators 存储了 generator，self._serials 记录一些辅助的信息
             min_request_key = min(self._generators.keys(), key=lambda serial: self._serials[serial]["timestamp"])
             timestamp = self._serials[min_request_key]["timestamp"]  # 所有已订阅数据中的最小行情时间
-            quotes_diff = self._serials[min_request_key]["quotes"]
-            if timestamp < self._current_dt and self._quotes.get(min_request_key[0], {}).get("sended_init_quote"):
-                # 先订阅 A 合约，再订阅 A 合约日线，那么 A 合约的行情时间会回退: 2021-01-04 09:31:59.999999 -> 2021-01-01 18:00:00.000000
-                # 如果当前 timestamp 小于 _current_dt，那么这个 quote_diff 不需要发到下游
-                # 如果先订阅 A 合约（有夜盘），时间停留在夜盘开始时间， 再订阅 B 合约（没有夜盘），那么 B 合约的行情（前一天收盘时间）应该发下去，
-                # 否则 get_quote(B) 等到收到行情才返回，会直接把时间推进到第二天白盘。
-                quotes_diff = None
+            is_before_current_dt = timestamp < self._current_dt  # 生成这笔行情的时间是否小于当前回测时间
             # 推进时间，一次只会推进最多一个(补数据时有可能是0个)行情时间，并确保<=该行情时间的行情都被发出
             # 如果行情时间大于当前回测时间 则 判断是否diff中已有数据；否则表明此行情时间的数据未全部保存在diff中，则继续append
             if timestamp > self._current_dt:
@@ -365,13 +351,17 @@ class TqBacktest(object):
             # klines 请求，需要记录已经发送 api 的数据
             for symbol in diff.get("klines", {}):
                 for dur in diff["klines"][symbol]:
-                    for kid in diff["klines"][symbol][dur]["data"]:
+                    for kid in diff["klines"][symbol][dur].get('data', {}):
                         rs = self._sended_to_api.setdefault((symbol, int(dur)), [])
                         kid = int(kid)
                         self._sended_to_api[(symbol, int(dur))] = _rangeset_range_union(rs, (kid, kid + 1))
-            quote_info = self._quotes[min_request_key[0]]
-            if quotes_diff and (quote_info["min_duration"] != 0 or min_request_key[1] == 0):
-                quotes[min_request_key[0]] = quotes_diff
+            # 记录用于生成 quote 的信息
+            quotes_helper[min_request_key] = {
+                "timestamp": timestamp,
+                "kline_or_tick": self._serials[min_request_key]["kline_or_tick"],
+                "when": self._serials[min_request_key]["when"],
+                "is_before_current_dt": is_before_current_dt,
+            }
             await self._fetch_serial(min_request_key)
         if self._had_any_generator and not self._generators and not self._diffs:  # 当无可发送数据时则抛出BacktestFinished例外,包括未订阅任何行情 或 所有已订阅行情的最后一笔行情获取完成
             self._api._print("回测结束")
@@ -384,7 +374,44 @@ class TqBacktest(object):
             })
             await self._api._wait_until_idle()
             raise BacktestFinished(self._api) from None
-        return quotes
+        # 把 quote 对应的 diffs 添加到 self._diffs 中
+        self._generator_quotes_diffs(quotes_helper)  # 生成 quotes_diffs
+
+    def _generator_quotes_diffs(self, quotes_helper) -> dict:
+        """
+        _generator_diffs 之后批量生成 quotes_diffs，支持只有最小周期 Kline 生成 high low 对应行情
+        https://shinnytech.atlassian.net/wiki/spaces/~245981717/pages/1527349338/tqsdk+high+low
+        """
+        for key in quotes_helper.keys():
+            ins, dur = key
+            symbol = ins.split(",")[0]
+            if quotes_helper[key]["is_before_current_dt"] and self._quotes.get(symbol, {}).get("sended_init_quote"):
+                # 先订阅 A 合约，再订阅 A 合约日线，那么 A 合约的行情时间会回退: 2021-01-04 09:31:59.999999 -> 2021-01-01 18:00:00.000000
+                # 如果当前 timestamp 小于 _current_dt，那么这个 quote_diff 不需要发到下游
+                # 如果先订阅 A 合约（有夜盘），时间停留在夜盘开始时间， 再订阅 B 合约（没有夜盘），那么 B 合约的行情（前一天收盘时间）应该发下去，
+                # 否则 get_quote(B) 等到收到行情才返回，会直接把时间推进到第二天白盘。
+                continue
+            item = quotes_helper[key]["kline_or_tick"]
+            if item is None:
+                # item 如果是 None 的话，没有可以生成行情的信息的数据，那么不生成 quote_diff
+                continue
+            diffs = None
+            if self._quotes[symbol]['min_duration'] == 0 and dur == 0:
+                # tick 生成行情
+                diffs = TqBacktest._get_quote_diffs_from_tick(symbol, item)
+            if self._quotes[symbol]['min_duration'] != 0:
+                # kline 生成行情
+                when = quotes_helper[key]["when"]
+                timestamp = quotes_helper[key]["timestamp"]  # quote 行情时间
+                quote_info = self._data["quotes"][symbol]
+                froms = ["open"] if when == "OPEN" else ["close"]
+                if when == "CLOSE" and self._quotes[symbol]['min_duration'] == dur:
+                    # kline 生成 quote 数据，只有该合约订阅的最小周期会生成 high low 对应的行情
+                    froms = ["high", "low", "close"]
+                diffs = TqBacktest._get_quote_diffs_from_kline(symbol, quote_info['price_tick'], timestamp, item, froms)
+            if diffs:
+                self._quotes[symbol]["sended_init_quote"] = True
+                self._diffs.extend(diffs)
 
     def _get_backtest_time(self) -> dict:
         if self._is_first_send:
@@ -401,7 +428,8 @@ class TqBacktest(object):
 
     async def _ensure_serial(self, ins, dur, chart_id=None):
         if (ins, dur) not in self._serials:
-            quote = self._quotes.setdefault(ins, {  # 在此处设置 min_duration: 每次生成K线的时候会自动生成quote, 记录某一合约的最小duration
+            symbol = ins.split(',')[0]
+            quote = self._quotes.setdefault(symbol, {  # 在此处设置 min_duration: 每次生成K线的时候会自动生成quote, 记录某一合约的最小duration
                 "min_duration": dur
             })
             quote["min_duration"] = min(quote["min_duration"], dur)
@@ -424,23 +452,28 @@ class TqBacktest(object):
             while not query_pack.items() <= self._data.get("symbols", {}).get(pack["query_id"], {}).items():
                 await update_chan.recv()
 
-    async def _ensure_quote(self, ins):
+    async def _ensure_symbols(self, symbols):
         # 在接新版合约服务器后，合约信息程序运行过程中查询得到的，这里不再能保证合约一定存在，需要添加 quote 默认值
-        quote = _get_obj(self._data, ["quotes", ins], BtQuote(self._api))
-        if math.isnan(quote.get("price_tick")):
-            query_pack = _query_for_quote(ins)
+        quotes = [_get_obj(self._data, ["quotes", symbol], BtQuote(self._api)) for symbol in symbols]
+        quotes = [q for q in quotes if math.isnan(q.get("price_tick"))]
+        if not quotes:
+            return
+        for query_pack in _query_for_quote([q._path[-1] for q in quotes], self._api._pre20_ins_info.keys()):
             await self._md_send_chan.send(query_pack)
-            async with TqChan(self._api, last_only=True) as update_chan:
-                quote["_listener"].add(update_chan)
-                while math.isnan(quote.get("price_tick")):
-                    await update_chan.recv()
-        if ins not in self._quotes or self._quotes[ins]["min_duration"] > 60000000000:
-            await self._ensure_serial(ins, 60000000000)
+        async with TqChan(self._api, last_only=True) as update_chan:
+            for q in quotes:
+                q["_listener"].add(update_chan)
+            while any([math.isnan(q.get("price_tick")) for q in quotes]):
+                await update_chan.recv()
+
+    async def _ensure_quote(self, symbol):
+        if symbol not in self._quotes or self._quotes[symbol]["min_duration"] > 60000000000:
+            await self._ensure_serial(symbol, 60000000000)
 
     async def _fetch_serial(self, key):
         s = self._serials[key]
         try:
-            s["timestamp"], s["diff"], s["quotes"] = await self._generators[key].__anext__()
+            s["timestamp"], s["diff"], s["kline_or_tick"], s["when"] = await self._generators[key].__anext__()
         except StopAsyncIteration:
             del self._generators[key]  # 删除一个行情时间超过结束时间的 generator
 
@@ -448,7 +481,7 @@ class TqBacktest(object):
         """k线/tick 序列的 async generator, yield 出来的行情数据带有时间戳, 因此 _send_diff 可以据此归并"""
         # 先定位左端点, focus_datetime 是 lower_bound ,这里需要的是 upper_bound
         # 因此将 view_width 和 focus_position 设置成一样，这样 focus_datetime 所对应的 k线刚好位于屏幕外
-        # 使用两个长度为 8964 的 chart，去缓存/回收下游需要的数据
+        # 使用两个长度为 10000 的 chart，去缓存/回收下游需要的数据
         chart_id_a = _generate_uuid("PYSDK_backtest")
         chart_id_b = _generate_uuid("PYSDK_backtest")
         chart_info = {
@@ -456,9 +489,9 @@ class TqBacktest(object):
             "chart_id": chart_id_a,
             "ins_list": ins,
             "duration": dur,
-            "view_width": 8964,  # 设为8964原因：可满足用户所有的订阅长度，并在backtest中将所有的 相同合约及周期 的K线用同一个serial存储
+            "view_width": 10000,  # 设为 10000 原因：可满足用户所有的订阅长度，并在backtest中将所有的 相同合约及周期 的K线用同一个serial存储
             "focus_datetime": int(self._current_dt),
-            "focus_position": 8964,
+            "focus_position": 10000,
         }
         chart_a = _get_obj(self._data, ["charts", chart_id_a])
         chart_b = _get_obj(self._data, ["charts", chart_id_b])
@@ -480,21 +513,34 @@ class TqBacktest(object):
                     if not (chart_info.items() <= _get_obj(chart, ["state"]).items()):
                         # 当前请求还没收齐回应, 不应继续处理
                         continue
-                    left_id = chart.get("left_id", -1)
-                    right_id = chart.get("right_id", -1)
-                    if (left_id == -1 and right_id == -1) or chart.get("more_data", True):
-                        continue  # 定位信息还没收到, 数据没有完全收到
+                    if not chart.get("ready", False):
+                        continue  # chart 数据还没准备好
                     last_id = serials[0].get("last_id", -1)
                     if last_id == -1:
-                        continue  # 数据序列还没收到
+                        # 所有合约的 tick 数据一定有，开盘一定会收到一笔 tick
+                        # kline 是由有价格的 tick 生成的，所以 kline 可能没有数据的
+                        assert dur > 0
+                        diff = {
+                            "klines": {
+                                symbol_list[0]: {
+                                    str(dur): {
+                                        "last_id": -1
+                                    }
+                                }
+                            }
+                        }
+                        yield self._current_dt, diff, None, "OPEN"
+                        return
                     if self._data.get("mdhis_more_data", True):
                         self._data["_listener"].add(update_chan)
                         continue
                     else:
                         self._data["_listener"].discard(update_chan)
+                    left_id = chart.get("left_id", -1)
+                    right_id = chart.get("right_id", -1)
                     if current_id is None:
                         current_id = max(left_id, 0)
-                    # 发送下一段 chart 8964 根 kline
+                    # 发送下一段 chart 10000 根 kline
                     chart_info["chart_id"] = chart_id_b if chart_info["chart_id"] == chart_id_a else chart_id_a
                     chart_info["left_kline_id"] = right_id
                     chart_info.pop("focus_datetime", None)
@@ -504,7 +550,7 @@ class TqBacktest(object):
                         if current_id > last_id:
                             # 当前 id 已超过 last_id
                             return
-                        # 将订阅的8964长度的窗口中的数据都遍历完后，退出循环，然后再次进入并处理下一窗口数据
+                        # 将订阅的10000长度的窗口中的数据都遍历完后，退出循环，然后再次进入并处理下一窗口数据
                         if current_id > right_id:
                             break
                         item = {k: v for k, v in serials[0]["data"].get(str(current_id), {}).items()}
@@ -515,14 +561,14 @@ class TqBacktest(object):
                                         "last_id": current_id,
                                         "data": {
                                             str(current_id): item,
-                                            str(current_id - 8964): None,
+                                            str(current_id - 10000): None,
                                         }
                                     }
                                 }
                             }
                             if item["datetime"] > self._end_dt:  # 超过结束时间
                                 return
-                            yield item["datetime"], diff, self._get_quotes_from_tick(item)
+                            yield item["datetime"], diff, item, "TICK"
                         else:
                             timestamp = item["datetime"] if dur < 86400000000000 else _get_trading_day_start_time(
                                 item["datetime"])
@@ -553,6 +599,7 @@ class TqBacktest(object):
                             for chart_id in self._serials[(ins, dur)]["chart_id_set"]:
                                 diff["charts"] = {
                                     chart_id: {
+                                        "left_id": current_id - 10000 + 1,  # left_id 是当前窗口的左端点
                                         "right_id": current_id  # api 中处理多合约 kline 需要 right_id 信息
                                     }
                                 }
@@ -581,10 +628,7 @@ class TqBacktest(object):
                                             }
                                         }
                                     }
-                            yield timestamp, diff, self._get_quotes_from_kline_open(
-                                self._data["quotes"][symbol_list[0]],
-                                timestamp,
-                                item)  # K线刚生成时的数据都为开盘价
+                            yield timestamp, diff, item, "OPEN"  # K线刚生成时的数据都为开盘价
                             timestamp = item["datetime"] + dur - 1000 \
                                 if dur < 86400000000000 else _get_trading_day_start_time(item["datetime"] + dur) - 1000
                             if timestamp > self._end_dt:  # 超过结束时间
@@ -613,9 +657,7 @@ class TqBacktest(object):
                                             }
                                         }
                                     }
-                            yield timestamp, diff, self._get_quotes_from_kline(self._data["quotes"][symbol_list[0]],
-                                                                               timestamp,
-                                                                               item)  # K线结束时生成quote数据
+                            yield timestamp, diff, item, "CLOSE"  # K线结束时生成quote数据
                         current_id += 1
             finally:
                 # 释放chart资源
@@ -677,59 +719,57 @@ class TqBacktest(object):
         return {"klines": gc_klines_diff}
 
     @staticmethod
-    def _get_quotes_from_tick(tick):
+    def _get_quote_diffs_from_tick(symbol, tick):
         quote = {k: v for k, v in tick.items()}
-        quote["datetime"] = datetime.fromtimestamp(tick["datetime"] / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f")
-        return [quote]
+        quote["datetime"] = _timestamp_nano_to_str(tick["datetime"])
+        return [{
+            "quotes": {
+                symbol: quote
+            }
+        }]
 
     @staticmethod
-    def _get_quotes_from_kline_open(info, timestamp, kline):
-        return [
-            {  # K线刚生成时的数据都为开盘价
-                "datetime": datetime.fromtimestamp(timestamp / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f"),
-                "ask_price1": kline["open"] + info["price_tick"],
-                "ask_volume1": 1,
-                "bid_price1": kline["open"] - info["price_tick"],
-                "bid_volume1": 1,
-                "last_price": kline["open"],
-                "highest": float("nan"),
-                "lowest": float("nan"),
-                "average": float("nan"),
-                "volume": 0,
-                "amount": float("nan"),
-                "open_interest": kline["open_oi"],
-            },
-        ]
-
-    @staticmethod
-    def _get_quotes_from_kline(info, timestamp, kline):
+    def _get_quote_diffs_from_kline(symbol, price_tick, timestamp, kline, froms: list):
         """
+        根据 kline 生成 quote
+        froms: 列表，每一项为以下 "open", "high", "low", "close" 之一，表示根据哪个价格生成 quote 盘口；
+            其中最后一项只能是 open 或 close，表示生成 quote 的最新价
+
         分为三个包发给下游：
         1. 根据 diff 协议，对于用户收到的最终结果没有影响
         2. TqSim 撮合交易会按顺序处理收到的包，分别比较 high、low、close 三个价格对应的买卖价
         3. TqSim 撮合交易只用到了买卖价，所以最新价只产生一次 close，而不会发送三次
+        4. 最高最低仅用于 TqSim 撮合交易，由最小周期生成
         """
-        return [
-            {
-                "datetime": datetime.fromtimestamp(timestamp / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f"),
-                "ask_price1": kline["high"] + info["price_tick"],
-                "ask_volume1": 1,
-                "bid_price1": kline["high"] - info["price_tick"],
-                "bid_volume1": 1,
-                "last_price": kline["close"],
-                "highest": float("nan"),
-                "lowest": float("nan"),
-                "average": float("nan"),
-                "volume": 0,
-                "amount": float("nan"),
-                "open_interest": kline["close_oi"],
-            },
-            {
-                "ask_price1": kline["low"] + info["price_tick"],
-                "bid_price1": kline["low"] - info["price_tick"],
-            },
-            {
-                "ask_price1": kline["close"] + info["price_tick"],
-                "bid_price1": kline["close"] - info["price_tick"],
-            }
-        ]
+        diffs = []
+        assert froms[-1] in ["open", "close"]
+        for index, key in enumerate(froms):
+            if index == 0:
+                diffs.append({
+                    "quotes": {
+                        symbol: {
+                            "datetime": _timestamp_nano_to_str(timestamp),
+                            "ask_price1": kline[key] + price_tick,
+                            "ask_volume1": 1,
+                            "bid_price1": kline[key] - price_tick,
+                            "bid_volume1": 1,
+                            "last_price": kline[froms[-1]],
+                            "highest": float("nan"),
+                            "lowest": float("nan"),
+                            "average": float("nan"),
+                            "volume": 0,
+                            "amount": float("nan"),
+                            "open_interest": kline[f'{froms[-1]}_oi'],
+                        }
+                    }
+                })
+            else:
+                diffs.append({
+                    "quotes": {
+                        symbol: {
+                            "ask_price1": kline[key] + price_tick,
+                            "bid_price1": kline[key] - price_tick,
+                        }
+                    }
+                })
+        return diffs
