@@ -8,20 +8,26 @@ import random
 import ssl
 import time
 import warnings
+import base64
 from abc import abstractmethod
-from datetime import datetime
 from logging import Logger
-from queue import Queue
 from typing import Optional
+from urllib.parse import urlparse
 
 import certifi
 import websockets
+import websockets.exceptions
+from packaging import version
 from shinny_structlog import ShinnyLoggerAdapter
 
+from tqsdk.datetime import _cst_now
 from tqsdk.diff import _merge_diff, _get_obj
 from tqsdk.entity import Entity
-from tqsdk.exceptions import TqBacktestPermissionError
+from tqsdk.exceptions import TqBacktestPermissionError, TqContextManagerError
 from tqsdk.utils import _generate_uuid
+from tqsdk.sm import SMContext, NullContext
+from tqsdk.zq_otg import ZqOtgContext
+from tqsdk.zq import ZqContext
 
 """
 优化代码结构，修改为
@@ -38,6 +44,9 @@ TqReconnectHandler
 """
 
 
+websocket_version_ge_14 = version.parse(websockets.__version__) >= version.parse("14.0")
+
+
 class ReconnectTimer(object):
 
     def __init__(self):
@@ -50,42 +59,17 @@ class ReconnectTimer(object):
             self.timer = time.time() + random.uniform(seconds, seconds * 2)
 
 
-class TqStreamReader(asyncio.StreamReader):
-
-    def __init__(self, *args, **kwargs):
-        super(TqStreamReader, self).__init__(*args, **kwargs)
-        self._start_read_message = None
-        self._read_size = 0
-
-    async def readexactly(self, n):
-        data = await super(TqStreamReader, self).readexactly(n)
-        if not self._start_read_message:
-            self._start_read_message = time.time()
-        self._read_size += n
-        return data
-
-
-class TqWebSocketClientProtocol(websockets.WebSocketClientProtocol):
-
-    def __init__(self, *args, **kwargs):
-        super(TqWebSocketClientProtocol, self).__init__(*args, **kwargs)
-        self.reader = TqStreamReader(limit=self.read_limit // 2, loop=self.loop)
-
-    async def handshake(self, *args, **kwargs) -> None:
-        try:
-            await super(TqWebSocketClientProtocol, self).handshake(*args, **kwargs)
-        except websockets.exceptions.InvalidStatusCode as e:
-            for h_key, h_value in self.response_headers.items():
-                if h_key == 'x-shinny-auth-check' and h_value == 'Backtest Permission Denied':
-                    raise TqBacktestPermissionError(
-                        "免费账户每日可以回测3次，今日暂无回测权限，需要购买专业版本后使用。升级网址：https://account.shinnytech.com") from None
-            raise
-
-    async def read_message(self):
-        message = await super().read_message()
-        self.reader._start_read_message = None
-        self.reader._read_size = 0
-        return message
+if websocket_version_ge_14:
+    # https://websockets.readthedocs.io/en/stable/reference/exceptions.html#module-websockets.exceptions
+    websocket_expect_exc = (
+        websockets.exceptions.ConnectionClosedError, websockets.exceptions.InvalidHandshake, websockets.exceptions.InvalidURI,
+        websockets.exceptions.InvalidState, websockets.exceptions.ProtocolError
+    )
+else:
+    websocket_expect_exc = (
+        websockets.exceptions.ConnectionClosed, websockets.exceptions.InvalidStatusCode, websockets.exceptions.InvalidURI,
+        websockets.exceptions.InvalidState, websockets.exceptions.ProtocolError
+    )
 
 
 class TqConnect(object):
@@ -108,30 +92,116 @@ class TqConnect(object):
         """启动websocket客户端"""
         self._api = api
         # 调整代码位置，方便 monkey patch
+        self._query_max_length = 50000  # ins_query 最大长度
         self._ins_list_max_length = 100000  # subscribe_quote 最大长度
-        self._subscribed_per_seconds = 100  # 每秒 subscribe_quote 请求次数限制
-        self._subscribed_queue = Queue(self._subscribed_per_seconds)
+        self._subscribed_ins_list_throttle = 100  # 超过该阈值的订阅请求将进行流控检查
+        self._subscribed_counts = 0
 
-        self._keywords["extra_headers"] = self._api._base_headers
-        self._keywords["create_protocol"] = TqWebSocketClientProtocol
-        if url.startswith("wss://"):
+        # websockets 14.0版本升级后用法有变化
+        if websocket_version_ge_14:
+            # https://websockets.readthedocs.io/en/stable/howto/upgrade.html#arguments-of-connect
+            self._keywords["additional_headers"] = self._api._base_headers
+            self._keywords["user_agent_header"] = None   # self._api._base_headers 里面已经包含了 "User-Agent"
+            self._keywords["process_exception"] = lambda exc: exc
+        else:
+            self._keywords["extra_headers"] = self._api._base_headers
+        url_info = urlparse(url)
+        cm = NullContext()
+        if url_info.scheme == "wss":
             ssl_context = ssl.create_default_context()
             ssl_context.load_verify_locations(certifi.where())
             self._keywords["ssl"] = ssl_context
+        elif url_info.scheme.startswith("sm"):
+            sm_info = url_info.path.split("/", 4)
+            cm = SMContext(self._logger, self._api, url_info.scheme, sm_info[1], base64.urlsafe_b64decode(sm_info[2]).decode("utf-8"), base64.urlsafe_b64decode(sm_info[3]).decode("utf-8"))
+            url_info = url_info._replace(path="/".join(sm_info[:1]+sm_info[4:]))
+        elif url_info.scheme.startswith("zqotg"):
+            cm = ZqOtgContext(self._api)
+        elif url_info.scheme.startswith("zq"):
+            cm = ZqContext(self._api)
+
         count = 0
-        while True:
-            try:
-                if not self._first_connect:
+        async with cm:
+            while True:
+                try:
+                    if isinstance(cm, (SMContext, ZqOtgContext, ZqContext)):
+                        url = await cm.get_url(url_info)
+                    if not self._first_connect:
+                        notify_id = _generate_uuid()
+                        notify = {
+                            "type": "MESSAGE",
+                            "level": "WARNING",
+                            "code": 2019112910,
+                            "conn_id": self._conn_id,
+                            "content": f"开始与 {url} 的重新建立网络连接",
+                            "url": url
+                        }
+                        self._logger.debug("websocket connection connecting")
+                        await recv_chan.send({
+                            "aid": "rtn_data",
+                            "data": [{
+                                "notify": {
+                                    notify_id: notify
+                                }
+                            }]
+                        })
+                    async with websockets.connect(url, **self._keywords) as client:
+                        # 发送网络连接建立的通知，code = 2019112901
+                        notify_id = _generate_uuid()
+                        notify = {
+                            "type": "MESSAGE",
+                            "level": "INFO",
+                            "code": 2019112901,
+                            "conn_id": self._conn_id,
+                            "content": "与 %s 的网络连接已建立" % url,
+                            "url": url
+                        }
+                        if not self._first_connect:  # 如果不是第一次连接, 即为重连
+                            # 发送网络连接重新建立的通知，code = 2019112902
+                            notify["code"] = 2019112902
+                            notify["level"] = "WARNING"
+                            notify["content"] = "与 %s 的网络连接已恢复" % url
+                            self._logger.debug("websocket reconnected")
+                        else:
+                            self._logger.debug("websocket connected")
+                        # 发送网络连接建立的通知，code = 2019112901 or 2019112902，这里区分了第一次连接和重连
+                        await self._api._wait_until_idle()
+                        await recv_chan.send({
+                            "aid": "rtn_data",
+                            "data": [{
+                                "notify": {
+                                    notify_id: notify
+                                }
+                            }]
+                        })
+                        count = 0
+                        self._api._reconnect_timer.set_count(count)
+                        send_task = self._api.create_task(self._send_handler(send_chan, client))
+                        try:
+                            async for msg in client:
+                                pack = json.loads(msg)
+                                await self._api._wait_until_idle()
+                                self._logger.debug("websocket received data", pack=msg)
+                                await recv_chan.send(pack)
+                        finally:
+                            await self._api._cancel_task(send_task)
+                # 希望做到的效果是遇到网络问题可以断线重连, 但是可能抛出的例外太多了(TimeoutError,socket.gaierror等), 又没有文档或工具可以理出 try 代码中所有可能遇到的例外
+                # 而这里的 except 又需要处理所有子函数及子函数的子函数等等可能抛出的例外, 因此这里只能遇到问题之后再补, 并且无法避免 false positive 和 false negative
+                except websocket_expect_exc + (asyncio.TimeoutError, OSError, EOFError, TqBacktestPermissionError, TqContextManagerError) as e:
+                    in_ops_time = _cst_now().hour == 19 and 0 <= _cst_now().minute <= 30
+                    # 发送网络连接断开的通知，code = 2019112911
                     notify_id = _generate_uuid()
                     notify = {
                         "type": "MESSAGE",
                         "level": "WARNING",
-                        "code": 2019112910,
+                        "code": 2019112911,
                         "conn_id": self._conn_id,
-                        "content": f"开始与 {url} 的重新建立网络连接",
+                        "content": f"与 {url} 的网络连接断开，请检查客户端及网络是否正常",
                         "url": url
                     }
-                    self._logger.debug("websocket connection connecting")
+                    if in_ops_time:
+                        notify['content'] += '，每日 19:00-19:30 为日常运维时间，请稍后再试'
+                    self._logger.debug("websocket connection closed", error=str(e))
                     await recv_chan.send({
                         "aid": "rtn_data",
                         "data": [{
@@ -140,91 +210,19 @@ class TqConnect(object):
                             }
                         }]
                     })
-                async with websockets.connect(url, **self._keywords) as client:
-                    # 发送网络连接建立的通知，code = 2019112901
-                    notify_id = _generate_uuid()
-                    notify = {
-                        "type": "MESSAGE",
-                        "level": "INFO",
-                        "code": 2019112901,
-                        "conn_id": self._conn_id,
-                        "content": "与 %s 的网络连接已建立" % url,
-                        "url": url
-                    }
-                    if not self._first_connect:  # 如果不是第一次连接, 即为重连
-                        # 发送网络连接重新建立的通知，code = 2019112902
-                        notify["code"] = 2019112902
-                        notify["level"] = "WARNING"
-                        notify["content"] = "与 %s 的网络连接已恢复" % url
-                        self._logger.debug("websocket reconnected")
-                    else:
-                        self._logger.debug("websocket connected")
-                    # 发送网络连接建立的通知，code = 2019112901 or 2019112902，这里区分了第一次连接和重连
-                    await self._api._wait_until_idle()
-                    await recv_chan.send({
-                        "aid": "rtn_data",
-                        "data": [{
-                            "notify": {
-                                notify_id: notify
-                            }
-                        }]
-                    })
-                    count = 0
+                    if isinstance(e, TqBacktestPermissionError):
+                        # 如果错误类型是用户无回测权限，直接返回
+                        raise
+                    if self._first_connect and in_ops_time:
+                        raise Exception(f'与 {url} 的连接失败，每日 19:00-19:30 为日常运维时间，请稍后再试')
+                    if self._first_connect:
+                        self._first_connect = False
+                    # 下次重连的时间距离现在当前时间秒数，会等待相应的时间，否则立即发起重连
+                    sleep_seconds = self._api._reconnect_timer.timer - time.time()
+                    if sleep_seconds > 0:
+                        await asyncio.sleep(sleep_seconds)
+                    count += 1
                     self._api._reconnect_timer.set_count(count)
-                    send_task = self._api.create_task(self._send_handler(send_chan, client))
-                    try:
-                        async for msg in client:
-                            pack = json.loads(msg)
-                            await self._api._wait_until_idle()
-                            self._logger.debug("websocket received data", pack=msg)
-                            await recv_chan.send(pack)
-                    finally:
-                        self._logger.debug("websocket connection info", current_time=time.time(),
-                                           start_read_message=client.reader._start_read_message,
-                                           read_size=client.reader._read_size)
-                        send_task.cancel()
-                        await send_task
-            # 希望做到的效果是遇到网络问题可以断线重连, 但是可能抛出的例外太多了(TimeoutError,socket.gaierror等), 又没有文档或工具可以理出 try 代码中所有可能遇到的例外
-            # 而这里的 except 又需要处理所有子函数及子函数的子函数等等可能抛出的例外, 因此这里只能遇到问题之后再补, 并且无法避免 false positive 和 false negative
-            except (websockets.exceptions.ConnectionClosed, websockets.exceptions.InvalidStatusCode,
-                    websockets.exceptions.InvalidState, websockets.exceptions.ProtocolError, OSError, EOFError,
-                    TqBacktestPermissionError) as e:
-                in_ops_time = datetime.now().hour == 19 and 0 <= datetime.now().minute <= 30
-                # 发送网络连接断开的通知，code = 2019112911
-                notify_id = _generate_uuid()
-                notify = {
-                    "type": "MESSAGE",
-                    "level": "WARNING",
-                    "code": 2019112911,
-                    "conn_id": self._conn_id,
-                    "content": f"与 {url} 的网络连接断开，请检查客户端及网络是否正常",
-                    "url": url
-                }
-                if in_ops_time:
-                    notify['content'] += '，每日 19:00-19:30 为日常运维时间，请稍后再试'
-                self._logger.debug("websocket connection closed", error=str(e))
-                await recv_chan.send({
-                    "aid": "rtn_data",
-                    "data": [{
-                        "notify": {
-                            notify_id: notify
-                        }
-                    }]
-                })
-                if isinstance(e, TqBacktestPermissionError):
-                    # 如果错误类型是用户无回测权限，直接返回
-                    raise
-                if self._first_connect and in_ops_time:
-                    raise Exception(f'与 {url} 的连接失败，每日 19:00-19:30 为日常运维时间，请稍后再试')
-            finally:
-                if self._first_connect:
-                    self._first_connect = False
-                # 下次重连的时间距离现在当前时间秒数，会等待相应的时间，否则立即发起重连
-                sleep_seconds = self._api._reconnect_timer.timer - time.time()
-                if sleep_seconds > 0:
-                    await asyncio.sleep(sleep_seconds)
-                count += 1
-                self._api._reconnect_timer.set_count(count)
 
     async def _send_handler(self, send_chan, client):
         """websocket客户端数据发送协程"""
@@ -233,11 +231,13 @@ class TqConnect(object):
                 if pack.get("aid") == "subscribe_quote":
                     if len(pack.get("ins_list", "")) > self._ins_list_max_length:
                         warnings.warn(f"订阅合约字符串总长度大于 {self._ins_list_max_length}，可能会引起服务器限制。", stacklevel=3)
-                    if self._subscribed_queue.full():
-                        first_time = self._subscribed_queue.get()
-                        if time.time() - first_time < 1:
-                            warnings.warn(f"1s 内订阅请求次数超过 {self._subscribed_per_seconds} 次，订阅多合约时推荐使用 api.get_quote_list 方法。", stacklevel=3)
-                    self._subscribed_queue.put(time.time())
+                    ins_list_counts = len(pack.get("ins_list", "").split(","))
+                    self._subscribed_counts += 1
+                    if ins_list_counts > self._subscribed_ins_list_throttle and ins_list_counts / self._subscribed_counts < 2:
+                        warnings.warn("订阅多合约时推荐使用 api.get_quote_list 方法批量订阅。", stacklevel=3)
+                if pack.get("aid") == "ins_query":
+                    if len(pack.get("query", "")) > self._query_max_length:
+                        warnings.warn(f"订阅合约信息字段总长度大于 {self._query_max_length}，可能会引起服务器限制。", stacklevel=3)
                 msg = json.dumps(pack)
                 await client.send(msg)
                 self._logger.debug("websocket send data", pack=msg)
@@ -265,7 +265,7 @@ class TqReconnect(object):
                     self._pending_diffs.extend(pack_data)
                     for d in pack_data:
                         # _merge_diff 之后， self._data 会用于判断是否接收到了完整截面数据
-                        _merge_diff(self._data, d, self._api._prototype, False)
+                        _merge_diff(self._data, d, self._api._prototype, persist=False, reduce_diff=False)
                     if self._is_all_received():
                         # 重连后收到完整数据截面
                         self._un_processed = False
@@ -298,7 +298,7 @@ class TqReconnect(object):
                         self._data = Entity()
                         self._data._instance_entity([])
                         for d in self._pending_diffs:
-                            _merge_diff(self._data, d, self._api._prototype, False)
+                            _merge_diff(self._data, d, self._api._prototype, persist=False, reduce_diff=False)
                         # 发送所有 resend_request
                         for msg in self._resend_request.values():
                             # 这里必须用 send_nowait 而不是 send，因为如果使用异步写法，在循环中，代码可能执行到 send_task, 可能会修改 _resend_request
@@ -308,8 +308,7 @@ class TqReconnect(object):
                     else:
                         await api_recv_chan.send(pack)
         finally:
-            send_task.cancel()
-            await asyncio.gather(send_task, return_exceptions=True)
+            await self._api._cancel_task(send_task)
 
     async def _send_handler(self, api_send_chan, ws_send_chan):
         async for pack in api_send_chan:
