@@ -8,14 +8,14 @@ import struct
 
 import numpy as np
 import pandas as pd
+from filelock import FileLock
 
 from tqsdk.channel import TqChan
 from tqsdk.diff import _get_obj
 from tqsdk.rangeset import _rangeset_difference, _rangeset_intersection
-from tqsdk.tafunc import get_dividend_df, get_dividend_factor
-from tqsdk.utils import _generate_uuid
+from tqsdk.utils import _generate_uuid, _get_dividend_factor
 
-CACHE_DIR = os.path.join(os.path.expanduser('~'), ".tqsdk/data_series")
+CACHE_DIR = os.path.join(os.path.expanduser('~'), ".tqsdk/data_series_1")
 
 
 class DataSeries:
@@ -67,97 +67,101 @@ class DataSeries:
         self._adj_type = adj_type
         self._dividend_cache = {}  # 缓存合约对应的复权系数矩阵，每个合约只计算一次
         self.df = pd.DataFrame()
-        self.is_ready = False
         DataSeries._ensure_cache_dir()  # 确认缓存文件夹存在
-        self._api.create_task(self._run())
+        self._task = self._api.create_task(self._run())
+
+    @property
+    def is_ready(self):
+        return self._task.done()
 
     async def _run(self):
         symbol = self._symbol_list[0]  # todo: 目前只处理一个合约的情况
-        # 检查缓存文件，计算需要下载的数据段
-        rangeset_id = DataSeries._get_rangeset_id(symbol, self._dur_nano)
-        rangeset_dt = DataSeries._get_rangeset_dt(symbol, self._dur_nano, rangeset_id)
-        DataSeries._assert_rangeset_asce_sorted(rangeset_id)
-        DataSeries._assert_rangeset_asce_sorted(rangeset_dt)
-        # 计算差集 todo: 已下载数据的 rangeset_id[0][0] ~ rangeset_id[-1][1] 覆盖到的部分，可以使用 id 范围下载，未覆盖到的使用 dt 范围下载
-        # rangeset_dt 中的最后一个 range 的最后一根 k 线，需要重新下载，因为如果用户填写的 end_dt_nano 是未来时间，有可能这跟 k 线数据是过时的
-        if len(rangeset_dt) > 0:
-            rangeset_dt[-1] = (rangeset_dt[-1][0], rangeset_dt[-1][1] - self._dur_nano)
-            if rangeset_dt[-1][0] == rangeset_dt[-1][1]:
-                # 如果最后一个 range 的只包含最后一根 k 线，则删去最后一个 Range，最后一根 k 线需要重新下载
-                rangeset_dt.pop(-1)
-        diff_rangeset = _rangeset_difference([(self._start_dt_nano, self._end_dt_nano)], rangeset_dt)
-
-        # 下载数据并全部完成
-        if len(diff_rangeset) > 0:
-            await self._download_data_series(diff_rangeset)
-            self._merge_rangeset()  # 归并文件
+        lock_path = DataSeries._get_lock_path(symbol, self._dur_nano)
+        with FileLock(lock_path, timeout=-1):
+            # 检查缓存文件，计算需要下载的数据段
             rangeset_id = DataSeries._get_rangeset_id(symbol, self._dur_nano)
             rangeset_dt = DataSeries._get_rangeset_dt(symbol, self._dur_nano, rangeset_id)
             DataSeries._assert_rangeset_asce_sorted(rangeset_id)
             DataSeries._assert_rangeset_asce_sorted(rangeset_dt)
+            # 计算差集 todo: 已下载数据的 rangeset_id[0][0] ~ rangeset_id[-1][1] 覆盖到的部分，可以使用 id 范围下载，未覆盖到的使用 dt 范围下载
+            # rangeset_dt 中的最后一个 range 的最后一根 k 线，需要重新下载，因为如果用户填写的 end_dt_nano 是未来时间，有可能这跟 k 线数据是过时的
+            if len(rangeset_dt) > 0:
+                rangeset_dt[-1] = (rangeset_dt[-1][0], rangeset_dt[-1][1] - self._dur_nano)
+                if rangeset_dt[-1][0] == rangeset_dt[-1][1]:
+                    # 如果最后一个 range 的只包含最后一根 k 线，则删去最后一个 Range，最后一根 k 线需要重新下载
+                    rangeset_dt.pop(-1)
+            diff_rangeset = _rangeset_difference([(self._start_dt_nano, self._end_dt_nano)], rangeset_dt)
 
-        assert len(rangeset_id) == len(rangeset_dt) > 0
+            # 下载数据并全部完成
+            if len(diff_rangeset) > 0:
+                await self._download_data_series(diff_rangeset)
+                self._merge_rangeset()  # 归并文件
+                rangeset_id = DataSeries._get_rangeset_id(symbol, self._dur_nano)
+                rangeset_dt = DataSeries._get_rangeset_dt(symbol, self._dur_nano, rangeset_id)
+                DataSeries._assert_rangeset_asce_sorted(rangeset_id)
+                DataSeries._assert_rangeset_asce_sorted(rangeset_dt)
 
-        # 查找用户请求时间段与已有数据时间段的交集
-        target_rangeset_dt = _rangeset_intersection([(self._start_dt_nano, self._end_dt_nano)], rangeset_dt)
-        assert len(target_rangeset_dt) <= 1  # 用户请求应该落在一个时间段内，或者用户请求的时间段内没有任何数据
-        if len(target_rangeset_dt) == 0:  # 用户请求的时间段内没有任何数据
-            self.is_ready = True
-            return
+            assert len(rangeset_id) == len(rangeset_dt)  # rangeset_id 和 rangeset_dt 的长度应该相等, 且一一对应，有可能长度都为 0 ，即没有下载任何数据
 
-        # 此时用户请求时间范围，转化为 target_rangeset_dt[0]
-        # 找到 self._start_dt_nano, self._end_dt_nano 对应的 range_id
-        (start_dt, end_dt) = target_rangeset_dt[0]
-        range_id = None
-        for index in range(len(rangeset_dt)):
-            range_dt = rangeset_dt[index]
-            if range_dt[0] <= start_dt and end_dt <= range_dt[1]:
-                range_id = rangeset_id[index]
-                break
-        assert range_id
+            # 查找用户请求时间段与已有数据时间段的交集
+            target_rangeset_dt = _rangeset_intersection([(self._start_dt_nano, self._end_dt_nano)], rangeset_dt)
+            assert len(target_rangeset_dt) <= 1  # 用户请求应该落在一个时间段内，或者用户请求的时间段内没有任何数据
+            if len(target_rangeset_dt) == 0:  # 用户请求的时间段内没有任何数据
+                return
 
-        # 返回 dataframe, 目标文件为
-        filename = os.path.join(CACHE_DIR, f"{symbol}.{self._dur_nano}.{range_id[0]}.{range_id[1]}")
-        data_cols = DataSeries._get_data_cols(symbol=self._symbol_list[0], dur_nano=self._dur_nano)
-        dtype = np.dtype([('id', 'i8'), ('datetime', 'i8')] + [(col, 'f8') for col in data_cols])
-        fp = np.memmap(filename, dtype=dtype, mode='r', shape=range_id[1] - range_id[0])
+            # 此时用户请求时间范围，转化为 target_rangeset_dt[0]
+            # 找到 self._start_dt_nano, self._end_dt_nano 对应的 range_id
+            (start_dt, end_dt) = target_rangeset_dt[0]
+            range_id = None
+            for index in range(len(rangeset_dt)):
+                range_dt = rangeset_dt[index]
+                if range_dt[0] <= start_dt and end_dt <= range_dt[1]:
+                    range_id = rangeset_id[index]
+                    break
+            assert range_id
 
-        # target_rangeset_dt[0] 对应的 id 范围是 [start_id, end_id)
-        start_id = fp[fp['datetime'] <= start_dt][-1]["id"]
-        end_id = fp[fp['datetime'] < end_dt][-1]["id"]
-        rows = end_id - start_id + 1  # 读取数据行数
-        array = fp[start_id - range_id[0]: start_id - range_id[0] + rows]
+            # 返回 dataframe, 目标文件为
+            filename = os.path.join(CACHE_DIR, f"{symbol}.{self._dur_nano}.{range_id[0]}.{range_id[1]}")
+            data_cols = DataSeries._get_data_cols(symbol=self._symbol_list[0], dur_nano=self._dur_nano)
+            dtype = np.dtype([('id', 'i8'), ('datetime', 'i8')] + [(col, 'f8') for col in data_cols])
+            fp = np.memmap(filename, dtype=dtype, mode='r', shape=range_id[1] - range_id[0])
 
-        # 按列赋值，df.append 方法会返回一个新的 df，初始化构造的 df 可能（如果是异步代码下）已经返回给用户代码中；df.update 方法会导致更新的列的 type 都是 object
-        self.df["id"] = array["id"]
-        self.df["datetime"] = array["datetime"]
-        for c in data_cols:
-            self.df[c] = array[c]
-        self.df["symbol"] = symbol
-        self.df["duration"] = self._dur_nano
+            # target_rangeset_dt[0] 对应的 id 范围是 [start_id, end_id)
+            start_id = fp[fp['datetime'] <= start_dt][-1]["id"]
+            end_id = fp[fp['datetime'] < end_dt][-1]["id"]
+            rows = end_id - start_id + 1  # 读取数据行数
+            array = fp[start_id - range_id[0]: start_id - range_id[0] + rows]
 
-        # 复权, 如果存在 STOCK / FUND 并且 adj_type is not None, 这里需要提前准备下载时间段内的复权因子
-        quote = self._api.get_quote(symbol)
-        if self._adj_type and quote.ins_class in ["STOCK", "FUND"]:
-            factor_df = await self._update_dividend_factor(symbol)  # 复权需要根据日线计算除权因子，todo: 如果本地下载过日线，不需要再从服务器获取日线数据
-            if self._adj_type == "F":
-                # 倒序循环 factor_df, 对于小于当前 factor_df[datetime] 的行 乘以 factor_df[factor]
-                for i in range(factor_df.shape[0] - 1, -1, -1):
-                    dt = factor_df.iloc[i].datetime
-                    factor = factor_df.iloc[i].factor
-                    adj_cols = DataSeries._get_adj_cols(symbol, self._dur_nano)
-                    lt = self.df["datetime"].lt(dt)
-                    self.df.loc[lt, adj_cols] = self.df.loc[lt, adj_cols] * factor
-            if self._adj_type == "B":
-                # 正序循环 factor_df, 对于大于等于当前 factor_df[datetime] 的行 乘以 1 / factor_df[factor]
-                for i in range(factor_df.shape[0]):
-                    dt = factor_df.iloc[i].datetime
-                    factor = factor_df.iloc[i].factor
-                    adj_cols = DataSeries._get_adj_cols(symbol, self._dur_nano)
-                    ge = self.df["datetime"].ge(dt)
-                    self.df.loc[ge, adj_cols] = self.df.loc[ge, adj_cols] / factor
-        # 结束状态
-        self.is_ready = True
+            # 按列赋值，df.append 方法会返回一个新的 df，初始化构造的 df 可能（如果是异步代码下）已经返回给用户代码中；df.update 方法会导致更新的列的 type 都是 object
+            self.df["id"] = array["id"]
+            self.df["datetime"] = array["datetime"]
+            for c in data_cols:
+                self.df[c] = array[c]
+            self.df["symbol"] = symbol
+            self.df["duration"] = self._dur_nano
+
+            # 复权, 如果存在 STOCK / FUND 并且 adj_type is not None, 这里需要提前准备下载时间段内的复权因子
+            quote = self._api.get_quote(symbol)
+            if self._adj_type and quote.ins_class in ["STOCK", "FUND"]:
+                factor_df = await _get_dividend_factor(self._api, quote, self._start_dt_nano, self._end_dt_nano,
+                                                       chart_id_prefix="PYSDK_data_factor")  # 复权需要根据日线计算除权因子，todo: 如果本地下载过日线，不需要再从服务器获取日线数据
+                if self._adj_type == "F":
+                    # 倒序循环 factor_df, 对于小于当前 factor_df[datetime] 的行 乘以 factor_df[factor]
+                    for i in range(factor_df.shape[0] - 1, -1, -1):
+                        dt = factor_df.iloc[i].datetime
+                        factor = factor_df.iloc[i].factor
+                        adj_cols = DataSeries._get_adj_cols(symbol, self._dur_nano)
+                        lt = self.df["datetime"].lt(dt)
+                        for col in adj_cols:
+                            self.df.loc[lt, col] = self.df.loc[lt, col] * factor
+                if self._adj_type == "B":
+                    # 正序循环 factor_df, 对于大于等于当前 factor_df[datetime] 的行 乘以 1 / factor_df[factor]
+                    for i in range(factor_df.shape[0]):
+                        dt = factor_df.iloc[i].datetime
+                        factor = factor_df.iloc[i].factor
+                        adj_cols = DataSeries._get_adj_cols(symbol, self._dur_nano)
+                        ge = self.df["datetime"].ge(dt)
+                        self.df.loc[ge, adj_cols] = self.df.loc[ge, adj_cols] / factor
 
     async def _download_data_series(self, rangeset):
         symbol = self._symbol_list[0]
@@ -181,8 +185,7 @@ class DataSeries:
                     target_filename = os.path.join(CACHE_DIR, f"{symbol}.{self._dur_nano}.{start_id}.{end_id + 1}")
                     shutil.move(temp_filename, target_filename)
             finally:
-                task.cancel()
-                await task
+                await self._api._cancel_task(task)
 
     async def _download_data(self, start_dt, end_dt, data_chan):
         # 下载的数据应该是 [start_dt, end_dt）
@@ -208,13 +211,12 @@ class DataSeries:
                 async for _ in update_chan:
                     if not (chart_info.items() <= _get_obj(chart, ["state"]).items()):
                         continue  # 当前请求还没收齐回应, 不应继续处理
+                    if chart.get("ready", False) is False:
+                        continue  # 数据还没全部收到
+                    if serial.get("last_id", -1) == -1:
+                        return  # 合约没有任何数据
                     left_id = chart.get("left_id", -1)
                     right_id = chart.get("right_id", -1)
-                    if (left_id == -1 and right_id == -1) or self._api._data.get("mdhis_more_data", True):
-                        continue  # 定位信息还没收到, 或数据序列还没收到
-                    # 检查合约的数据是否收到
-                    if serial.get("last_id", -1) == -1:
-                        continue
                     if current_id is None:
                         current_id = max(left_id, 0)
                     while current_id <= right_id:
@@ -241,51 +243,6 @@ class DataSeries:
                 "view_width": 2000,
             })
 
-    async def _update_dividend_factor(self, symbol):
-        quote = self._api.get_quote(symbol)
-        df = get_dividend_df(quote.stock_dividend_ratio, quote.cash_dividend_ratio)
-        between = df["datetime"].between(self._start_dt_nano, self._end_dt_nano)  # 只需要开始时间～结束时间之间的复权因子
-        df["pre_close"] = float('nan')
-        for i in df[between].index:
-            chart_info = {
-                "aid": "set_chart",
-                "chart_id": _generate_uuid("PYSDK_data_factor"),
-                "ins_list": symbol,
-                "duration": 86400 * 1000000000,
-                "view_width": 2,
-                "focus_datetime": int(df.iloc[i].datetime),
-                "focus_position": 1
-            }
-            await self._api._send_chan.send(chart_info)
-            chart = _get_obj(self._api._data, ["charts", chart_info["chart_id"]])
-            serial = _get_obj(self._api._data, ["klines", symbol, str(86400000000000)])
-            try:
-                async with self._api.register_update_notify() as update_chan:
-                    async for _ in update_chan:
-                        if not (chart_info.items() <= _get_obj(chart, ["state"]).items()):
-                            continue  # 当前请求还没收齐回应, 不应继续处理
-                        left_id = chart.get("left_id", -1)
-                        right_id = chart.get("right_id", -1)
-                        if (left_id == -1 and right_id == -1) or self._api._data.get("mdhis_more_data",
-                                                                                     True) or serial.get("last_id",
-                                                                                                         -1) == -1:
-                            continue  # 定位信息还没收到, 或数据序列还没收到, 合约的数据是否收到
-                        last_item = serial["data"].get(str(left_id), {})
-                        # 复权时间点的昨收盘
-                        df.loc[i, 'pre_close'] = last_item['close'] if last_item.get('close') else float('nan')
-                        break
-            finally:
-                await self._api._send_chan.send({
-                    "aid": "set_chart",
-                    "chart_id": chart_info["chart_id"],
-                    "ins_list": "",
-                    "duration": 86400000000000,
-                    "view_width": 2
-                })
-        df["factor"] = (df["pre_close"] - df["cash_dividend"]) / df["pre_close"] / (1 + df["stock_dividend"])
-        df["factor"].fillna(1, inplace=True)
-        return df
-
     def _merge_rangeset(self):
         symbol = self._symbol_list[0]
         rangeset = DataSeries._get_rangeset_id(symbol, self._dur_nano)
@@ -382,13 +339,17 @@ class DataSeries:
         if not os.path.exists(CACHE_DIR):
             os.makedirs(CACHE_DIR, exist_ok=True)
 
+    @staticmethod
+    def _get_lock_path(symbol, dur_nano):
+        return os.path.join(CACHE_DIR, f".{symbol}.{dur_nano}.lock")
+
     @staticmethod
     def _get_data_cols(symbol, dur_nano):
         # 获取数据列
         if dur_nano != 0:
             return ["open", "high", "low", "close", "volume", "open_oi", "close_oi"]
         else:
-            cols = ["last_price", "highest", "lowest", "volume", "amount", "open_interest"]
+            cols = ["last_price", "highest", "lowest", "average", "volume", "amount", "open_interest"]
             price_length = 5 if symbol.split('.')[0] in {"SHFE", "SSE", "SZSE"} else 1
             for i in range(1, price_length + 1):
                 cols.extend(f"{x}{i}" for x in ["bid_price", "bid_volume", "ask_price", "ask_volume"])
@@ -400,7 +361,7 @@ class DataSeries:
         if dur_nano != 0:
             return ["open", "high", "low", "close"]
         else:
-            cols = ["last_price", "highest", "lowest"]
+            cols = ["last_price", "highest", "lowest", "average"]
             price_length = 5 if symbol.split('.')[0] in {"SHFE", "SSE", "SZSE"} else 1
             cols.extend(f"{x}{i}" for x in ["bid_price", "ask_price"] for i in range(1, price_length + 1))
             return cols
