@@ -14,7 +14,7 @@ from tqsdk import TqApi, TqAuth, TargetPosTask
 SYMBOL = "SHFE.au2012"
 N = 15
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 klines = api.get_kline_serial(SYMBOL, 60 * 60 * 24, N)
 quote = api.get_quote(SYMBOL)
 target_pos = TargetPosTask(api, SYMBOL)
