@@ -4,7 +4,7 @@ __author__ = 'ringo'
 
 from tqsdk import TqApi, TqAuth
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 
 ls = api.query_options("SHFE.au2012")
 print(ls)  # 标的为 "SHFE.au2012" 的所有期权
@@ -18,7 +18,7 @@ print(ls)  # 标的为 "SHFE.au2012" 的看跌期权, 未下市的
 ls = api.query_options("SHFE.au2012", strike_price=340)
 print(ls)  # 标的为 "SHFE.au2012" 、行权价为 340 的期权
 
-ls = api.query_options("SSE.510300", exchange_id="CFFEX")
+ls = api.query_options("SSE.000300", exchange_id="CFFEX")
 print(ls)  # 中金所沪深300股指期权
 
 ls = api.query_options("SSE.510300", exchange_id="SSE")
