@@ -4,7 +4,7 @@ from tqsdk import TqApi, TqAuth
 如果买入看涨期权构建多头期货的价格小于卖出期货价格
 存在套利机会则发出双边挂单
 '''
-api = TqApi(auth=TqAuth("信易账户", "账号密码"))
+api = TqApi(auth=TqAuth("快期账户", "账号密码"))
 
 # 获取行权价为2950的MA109看涨期权的quote数据
 quote_option = api.get_quote('CZCE.MA109C2950')
@@ -20,7 +20,7 @@ while True:
     # 以对手价来计算买入看涨期权然后行权后的期货成本价格
     option_buy = quote_option.strike_price + quote_option.ask_price1
     # 判断当期货的买入1档，即卖出期货价格大于买入看涨期权的期货成本价格，形成套利空间时进行限价下单
-    if quote.bid_price1 < option_buy and times == 0:
+    if quote.bid_price1 > option_buy and times == 0:
         times += 1
         # 以现在卖1档价格买入看涨期权
         order_opiton = api.insert_order('CZCE.MA109C2950', "BUY", "OPEN", 1, quote_option.ask_price1)
