@@ -7,7 +7,7 @@ from tqsdk.tafunc import time_to_datetime
 '''
 from tqsdk import TqApi, TqAuth
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 
 quote = api.get_quote("SSE.510300")
 
