@@ -10,7 +10,7 @@ from tqsdk import TqApi, TqAuth, TqReplay
 复盘 2020-05-26 行情
 '''
 # 在创建 api 实例时传入 TqReplay 就会进入复盘模式
-api = TqApi(backtest=TqReplay(date(2020, 5, 26)), auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(backtest=TqReplay(date(2020, 5, 26)), auth=TqAuth("快期账户", "账户密码"))
 quote = api.get_quote("SHFE.cu2009")
 
 while True:
