@@ -5,7 +5,7 @@ __author__ = 'chengzhi'
 from tqsdk import TqApi, TqAuth
 import datetime
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 # 获得 i2209 tick序列的引用
 ticks = api.get_tick_serial("DCE.i2209")
 # 获得 i2209 10秒K线的引用
