@@ -3,7 +3,7 @@
 
 from tqsdk import TqApi, TqAuth
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 quote = api.get_quote("SHFE.ni2206")
 # 开仓两手并等待完成
 order = api.insert_order(symbol="SHFE.ni2206", direction="BUY", offset="OPEN", limit_price=quote.ask_price1, volume=2)
