@@ -6,10 +6,10 @@ from tqsdk import TqApi, TqAuth
 from tqsdk.tafunc import time_to_datetime
 
 '''
-使用get_trading_status来判断合约是否进入交易状态来进行下单，该接口需要有天勤量化专业版资格才可使用
+使用get_trading_status来判断合约是否进入交易状态来进行下单
 '''
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 ts = api.get_trading_status("SHFE.cu2201")
 print(ts.trade_status)
 
