@@ -11,7 +11,7 @@ from tqsdk.ta import MA
 注意: 画图示例中用到的数据不含有实际意义，请根据自己的实际策略情况进行修改
 '''
 
-api = TqApi(web_gui=":9878", auth=TqAuth("信易账户", "账户密码"))  # web_gui="[ip]:port", 指定 web 界面地址的 ip 和 port
+api = TqApi(web_gui=":9878", auth=TqAuth("快期账户", "账户密码"))  # web_gui="[ip]:port", 指定 web 界面地址的 ip 和 port
 klines = api.get_kline_serial("SHFE.rb2105", 24 * 60 * 60)
 
 while True:
