@@ -9,7 +9,7 @@ from tqsdk import TqApi, TqAuth
 注意: 画图示例中用到的数据不含有实际意义，请根据自己的实际策略情况进行修改
 '''
 
-api = TqApi(web_gui=True, auth=TqAuth("信易账户", "账户密码"))  # web_gui=True, 开启使用 web 界面查看绘图结果的功能
+api = TqApi(web_gui=True, auth=TqAuth("快期账户", "账户密码"))  # web_gui=True, 开启使用 web 界面查看绘图结果的功能
 klines = api.get_kline_serial("SHFE.rb2105", 300)
 
 # 示例1: 在主图中最后一根K线上画射线以标注需要的信号
