@@ -4,7 +4,7 @@ __author__ = "Ringo"
 
 from tqsdk import TqApi, TqAuth
 
-api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+api = TqApi(auth=TqAuth("快期账户", "账户密码"))
 
 # 订阅螺纹钢主连
 quote = api.get_quote("KQ.m@SHFE.rb")
