@@ -4,7 +4,6 @@ __author__ = 'chengzhi'
 
 import asyncio
 import time
-from datetime import datetime
 from asyncio import gather
 from inspect import isfunction
 from typing import Optional, Union, Callable
@@ -13,7 +12,7 @@ from tqsdk import utils
 from tqsdk.api import TqApi
 from tqsdk.backtest import TqBacktest
 from tqsdk.channel import TqChan
-from tqsdk.datetime import _is_in_trading_time
+from tqsdk.datetime import _is_in_trading_time, _timestamp_nano_to_str
 from tqsdk.diff import _get_obj
 from tqsdk.lib.utils import _check_volume_limit, _check_direction, _check_offset, _check_volume, _check_price, \
     _check_offset_priority
@@ -76,9 +75,11 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
         **注意:**
             1. TargetPosTask 在 set_target_volume 时并不下单或撤单, 它的下单和撤单动作, 是在之后的每次 wait_update 时执行的. 因此, **需保证 set_target_volume 后还会继续调用wait_update()** 。
 
-            2. 请勿在使用 TargetPosTask 的同时使用 insert_order() 函数, 否则将导致 TargetPosTask 报错或错误下单。
+            2. TargetPosTask 在每次下单后会根据后续的行情计算下单的最新的价格，当该价格发生变化则首先撤回由该程序发出的在场的委托，然后根据最新的价格重新下单。
 
-            3. TargetPosTask 如果同时设置 min_volume（每笔最小下单手数），max_volume（每笔最大下单的手数）两个参数，表示采用 **大单拆分模式** 下单。
+            3. 请勿在使用 TargetPosTask 的同时使用 insert_order() 函数, 否则将导致 TargetPosTask 报错或错误下单。
+
+            4. TargetPosTask 如果同时设置 min_volume（每笔最小下单手数），max_volume（每笔最大下单的手数）两个参数，表示采用 **大单拆分模式** 下单。
 
                 在 **大单拆分模式** 下，每次下单的手数为随机生成的正整数，值介于 min_volume、max_volume 之间。
 
@@ -96,9 +97,9 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
 
             symbol (str): 负责调整的合约代码
 
-            price (str / Callable): [可选]下单方式, 默认为 "ACTIVE"。
+            price (str / Callable): [可选]下单方式, 默认为 "ACTIVE"
                 * "ACTIVE"：对价下单，在持仓调整过程中，若下单方向为买，对价为卖一价；若下单方向为卖，对价为买一价。
-                * "PASSIVE"：排队价下单，在持仓调整过程中，若下单方向为买，对价为买一价；若下单方向为卖，对价为卖一价。
+                * "PASSIVE"：排队价下单，在持仓调整过程中，若下单方向为买，对价为买一价；若下单方向为卖，对价为卖一价，该种方式可能会造成较多撤单.
                 * Callable[[str], Union[float, int]]: 函数参数为下单方向，函数返回值是下单价格。如果返回 nan，程序会抛错。
 
             offset_priority (str): [可选]开平仓顺序，昨=平昨仓，今=平今仓，开=开仓，逗号=等待之前操作完成
@@ -147,22 +148,24 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
         Example2::
 
             # ... 用户代码 ...
-            quote1 = api.get_quote("SHFE.cu2012")
-            quote2 = api.get_quote("SHFE.au2012")
+            quote_list = api.get_quote_list(["SHFE.cu2012","SHFE.au2012"])
 
-            def get_price(direction, quote):
-                # 在 BUY 时使用买一价加一档价格，SELL 时使用卖一价减一档价格
-                if direction == "BUY":
-                    price = quote.bid_price1 + quote.price_tick
-                else:
-                    price = quote.ask_price1 - quote.price_tick
-                # 如果 price 价格是 nan，使用最新价报单
-                if price != price:
-                    price = quote.last_price
-                return price
+            def get_price_by_quote(quote):
+                def get_price(direction):
+                    # 在 BUY 时使用涨停价，SELL 时使用跌停价
+                    if direction == "BUY":
+                        price = quote["upper_limit"]
+                    else:
+                        price = quote.lower_limit
+                    # 如果 price 价格是 nan，使用最新价报单
+                    if price != price:
+                        price = quote.last_price
+                    return price
+                return get_price
+
+            for quote in quote_list:
+                target_pos_active_dict[quote.instrument_id] = TargetPosTask(api, quote.instrument_id, price=get_price_by_quote(quote))
 
-            target_pos1 = TargetPosTask(api, "SHFE.cu2012", price=lambda direction: get_price(direction, quote1))
-            target_pos2 = TargetPosTask(api, "SHFE.au2012", price=lambda direction: get_price(direction, quote2))
             # ... 用户代码 ...
 
         Example3::
@@ -170,7 +173,7 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
             # 大单拆分模式用法示例
 
             from tqsdk import TqApi, TqAuth, TargetPosTask
-            api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+            api = TqApi(auth=TqAuth("快期账户", "账户密码"))
             position = api.get_position('SHFE.rb2106')
 
             # 同时设置 min_volume、max_volume 两个参数，表示使用大单拆分模式
@@ -195,17 +198,15 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
             # 2021-03-15 11:29:48 -     INFO - 时间: 2021-03-15 11:29:47.533515, 合约: SHFE.rb2106, 开平: OPEN, 方向: BUY, 手数: 3, 价格: 4687.000,手续费: 14.12
 
         """
-        if symbol.startswith("CZCE.CJ"):
-            raise Exception("红枣期货不支持创建 targetpostask、twap、vwap 任务，交易所规定该品种最小开仓手数为大于等于 4 手，这些函数还未支持该规则!")
         super(TargetPosTask, self).__init__()
         self._api = api
-        self._account = account
+        self._account = api._account._check_valid(account)
         self._symbol = symbol
         self._exchange = symbol.split(".")[0]
         self._offset_priority = _check_offset_priority(offset_priority)
         self._min_volume, self._max_volume = _check_volume_limit(min_volume, max_volume)
         self._price = _check_price(price)
-        self._pos = self._api.get_position(self._symbol, account)
+        self._pos = self._account.get_position(self._symbol)
         self._pos_chan = TqChan(self._api, last_only=True)
         self._trade_chan = trade_chan
         self._trade_objs_chan = trade_objs_chan
@@ -213,6 +214,32 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
         self._time_update_task = self._api.create_task(self._update_time_from_md())  # 监听行情更新并记录当时本地时间的task
         self._local_time_record = time.time() - 0.005  # 更新最新行情时间时的本地时间
         self._local_time_record_update_chan = TqChan(self._api, last_only=True)  # 监听 self._local_time_record 更新
+        self._wait_task_finished = self._api._loop.create_future()
+        self._task.add_done_callback(lambda _: self._api.create_task(self._exit_task()))
+
+    async def _exit_task(self):
+        """
+        执行 task.cancel() 时, 删除掉该 symbol 对应的 TargetPosTask 实例，以释放占有的资源。
+
+        当用户代码为：
+        t = TargetPosTask(api, 'SHFE.rb2106', min_volume=2, max_volume=10)
+        t.cancel()
+        await asyncio.gather(t._task, return_exceptions=True)
+
+        以上代码执行后，t._task 中的 finally 部分没有被执行过，因为 t._task 本身从来没有被执行过。
+
+        所以这里用 add_done_callback 的方式，处理 __init__ 方法中创建的资源。
+        self._task、self._pos_chan、self._time_update_task 都是在 __init__ 方法里创建的资源，所以在这里释放资源，
+        self._task 中的 finally 部分只处理在 self._task 函数里创建的资源。
+        """
+        # self._account 类型为 TqSim/TqKq/TqAccount，都包括 _account_key 变量
+        TargetPosTaskSingleton._instances.pop(self._account._account_key + "#" + self._symbol, None)
+        await self._pos_chan.close()
+        await self._api._cancel_task(self._time_update_task)
+        self._wait_task_finished.set_result(True)
+
+    def __await__(self):
+        return self._wait_task_finished.__await__()
 
     def set_target_volume(self, volume: int) -> None:
         """
@@ -226,7 +253,7 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
             # 设置 rb1810 持仓为多头5手
             from tqsdk import TqApi, TqAuth, TargetPosTask
 
-            api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+            api = TqApi(auth=TqAuth("快期账户", "账户密码"))
             target_pos = TargetPosTask(api, "SHFE.rb1810")
             target_pos.set_target_volume(5)
             while True:
@@ -240,7 +267,7 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
 
             account1 = TqAccount("H海通期货", "123456", "123456")
             account2 = TqAccount("H宏源期货", "654321", "123456")
-            api = TqApi(TqMultiAccount([account1, account2]), auth=TqAuth("信易账户", "账户密码"))
+            api = TqApi(TqMultiAccount([account1, account2]), auth=TqAuth("快期账户", "账户密码"))
             symbol1 = "DCE.m2105"
             symbol2 = "DCE.i2101"
             # 多账户模式下, 调仓工具需要指定账户实例
@@ -330,6 +357,12 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
         all_tasks = []
         try:
             self._quote = await self._api.get_quote(self._symbol)
+            # 判断最小下单手数是否大于1
+            if self._quote.open_min_market_order_volume > 1 or self._quote.open_min_limit_order_volume > 1:
+                raise Exception(
+                    f"交易所规定 {self._symbol} 最小市价开仓手数 ({self._quote.open_min_market_order_volume})"
+                    f" 或最小限价开仓手数 ({self._quote.open_min_limit_order_volume}) 大于 1，targetpostask、twap、vwap 这些函数还未支持该规则!比如A合约最小开仓手数限制为3手，当要下单5手时是可以直接被下单的，但是如果部分成交了4手，剩余的1手在撤销后是无法重新下单的，因此无法对这些合约使用targetpostask"
+                )
             async for target_pos in self._pos_chan:
                 # lib 中对于时间判断的方案:
                 #   如果当前时间（模拟交易所时间）不在交易时间段内，则：等待直到行情更新
@@ -339,7 +372,7 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
                 while True:
                     if isinstance(self._api._backtest, TqBacktest):
                         cur_timestamp = self._api._data.get("_tqsdk_backtest", {}).get("current_dt", float("nan"))
-                        cur_dt = datetime.fromtimestamp(cur_timestamp / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f")
+                        cur_dt = _timestamp_nano_to_str(cur_timestamp)
                         time_record = float("nan")
                     else:
                         cur_dt = self._quote["datetime"]
@@ -372,12 +405,7 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
                     all_tasks.append(order_task)
                     delta_volume -= order_volume if order_dir == "BUY" else -order_volume
         finally:
-            # 执行 task.cancel() 时, 删除掉该 symbol 对应的 TargetPosTask 实例
-            # self._account 类型为 TqSim/TqKq/TqAccount，都包括 _account_key 变量
-            TargetPosTaskSingleton._instances.pop(self._account._account_key + "#" + self._symbol, None)
-            await self._pos_chan.close()
-            self._time_update_task.cancel()
-            await asyncio.gather(*([t._task for t in all_tasks] + [self._time_update_task]), return_exceptions=True)
+            await asyncio.gather(*[t._task for t in all_tasks], return_exceptions=True)
 
     def cancel(self):
         """
@@ -392,7 +420,7 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
             from datetime import datetime, time
             from tqsdk import TqApi, TargetPosTask
 
-            api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+            api = TqApi(auth=TqAuth("快期账户", "账户密码"))
             quote = api.get_quote("SHFE.rb2110")
             target_pos_passive = TargetPosTask(api, "SHFE.rb2110", price="PASSIVE")
 
@@ -416,6 +444,46 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
 
             api.close()
 
+
+        Example2::
+
+            # 在异步代码中使用
+            from datetime import datetime, time
+            from tqsdk import TqApi, TargetPosTask
+
+            api = TqApi(auth=TqAuth("快期账户", "账户密码"))
+            quote = api.get_quote("SHFE.rb2110")
+
+            async def demo(SYMBOL):
+                quote = await api.get_quote(SYMBOL)
+                target_pos_passive = TargetPosTask(api, SYMBOL, price="PASSIVE")
+                async with api.register_update_notify() as update_chan:
+                    async for _ in update_chan:
+                        if datetime.strptime(quote.datetime, "%Y-%m-%d %H:%M:%S.%f").time() < time(14, 50):
+                            # ... 策略代码 ...
+                        else:
+                            target_pos_passive.cancel()  # 取消 TargetPosTask 实例
+                            await target_pos_passive  # 等待 target_pos_passive 处理 cancel 结束
+                            break
+
+                target_pos_active = TargetPosTask(api, "SHFE.rb2110", price="ACTIVE")
+                target_pos_active.set_target_volume(0)  # 平所有仓位
+                pos = await api.get_position(SYMBOL)
+                async with api.register_update_notify() as update_chan:
+                    async for _ in update_chan:
+                        if pos.pos == 0:
+                            target_pos_active.cancel()  # 取消 TargetPosTask 实例
+                            await target_pos_active  # 等待 target_pos_active 处理 cancel 结束
+                            break
+
+
+            symbol_list = ["SHFE.rb2107", "DCE.m2109"]  # 设置合约代码
+            for symbol in symbol_list:
+                api.create_task(demo(symbol))  # 为每个合约创建异步任务
+
+            while True:
+                api.wait_update()
+
         """
         self._task.cancel()
 
@@ -426,7 +494,10 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
         Returns:
             bool: 当前 TargetPosTask 实例是否已经结束
         """
-        return self._task.done()
+        if self._wait_task_finished.done():
+            assert self._task.done() is True
+            return self._wait_task_finished.result()
+        return False
 
 
 class InsertOrderUntilAllTradedTask(object):
