@@ -4,38 +4,10 @@ __author__ = 'chengzhi'
 
 import copy
 import json
-import warnings
+from typing import List
 
-from tqsdk.datetime import _get_expire_rest_days
 from tqsdk.diff import _get_obj
 from tqsdk.entity import Entity
-from tqsdk.utils import _query_for_init, _generate_uuid
-
-
-class QuotesEntity(Entity):
-
-    def __init__(self, api):
-        self._api = api
-        self._not_send_init_query = True
-
-    def __iter__(self):
-        message = """
-            不推荐使用 api._data['quotes'] 获取全部合约，该使用方法会在 20201101 之后的版本中放弃维护。
-            需要注意：
-            * 在同步代码中，初次使用 api._data['quotes'] 获取全部合约会产生一个耗时很长的查询。
-            * 在协程中，api._data['quotes'] 这种用法不支持使用。
-            请尽快修改使用新的接口，参考链接 http://doc.shinnytech.com/tqsdk/reference/tqsdk.api.html#tqsdk.api.TqApi.query_quotes
-        """
-        warnings.warn(message, DeprecationWarning, stacklevel=3)
-        self._api._logger.warning("deprecation", content="Deprecation Warning in api._data['quotes']")
-
-        # 兼容旧版 tqsdk 所做的修改，来支持用户使用 for k,v in api._data.quotes.items() 类似的用法
-        # 从 api._init_() 最后 3 行移到这里
-        if self._not_send_init_query and self._api._stock:
-            self._not_send_init_query = False
-            q = _query_for_init()
-            self._api.query_graphql(q, {}, _generate_uuid("PYSDK_quote"))
-        return super().__iter__()
 
 
 class Quote(Entity):
@@ -129,13 +101,21 @@ class Quote(Entity):
         self.min_limit_order_volume: int = 0
         #: 最小市价单手数
         self.min_market_order_volume: int = 0
+        #: 最大市价开仓手数
+        self.open_max_market_order_volume: int = 0
+        #: 最大限价开仓手数
+        self.open_max_limit_order_volume: int = 0
+        #: 最小市价开仓手数
+        self.open_min_market_order_volume: int = 0
+        #: 最小限价开仓手数
+        self.open_min_limit_order_volume: int = 0
         #: 标的合约
         self.underlying_symbol: str = ""
         #: 行权价
         self.strike_price: float = float("nan")
         #: 合约类型
         self.ins_class: str = ""
-        #: 交易所内的合约代码
+        #: 合约代码，包含了交易所代码
         self.instrument_id: str = ""
         #: 合约中文名
         self.instrument_name: str = ""
@@ -173,6 +153,10 @@ class Quote(Entity):
         self.cash_dividend_ratio: list = []
         #: 距离到期日的剩余天数（自然日天数），正数表示距离到期日的剩余天数，0表示到期日当天，负数表示距离到期日已经过去的天数
         self.expire_rest_days: int = float('nan')
+        #: 板块信息
+        self.categories: List[CategoryInfo] = []
+        #: 持仓限额
+        self.position_limit: int = 0
 
     def _instance_entity(self, path):
         super(Quote, self)._instance_entity(path)
@@ -195,9 +179,19 @@ class Quote(Entity):
         return self._task.__await__()
 
 
+class CategoryInfo(Entity):
+    """CategoryInfo 是一个板块信息对象"""
+
+    def __init__(self):
+        #: 板块代码
+        self.id: str = ""
+        #: 板块名称
+        self.name: str = ""
+
+
 class TradingTime(Entity):
     """ TradingTime 是一个交易时间对象
-        它不是一个可单独使用的类，而是用于定义 Qoute 的 trading_time 字段的类型
+        它不是一个可单独使用的类，而是用于定义 Quote 的 trading_time 字段的类型
 
         (每个连续的交易时间段是一个列表，包含两个字符串元素，分别为这个时间段的起止点)"""
 
@@ -451,7 +445,7 @@ class Position(Entity):
     @property
     def orders(self):
         """
-        与此持仓相关的开仓/平仓挂单
+        与此持仓相关的且目前委托单状态为ALIVE的开仓/平仓挂单
 
         :return: dict, 其中每个元素的key为委托单ID, value为 :py:class:`~tqsdk.objs.Order`
         """
