@@ -3,19 +3,19 @@
 __author__ = 'mayanqiong'
 
 from collections import namedtuple
-from datetime import datetime
 from typing import Callable, Tuple
 
 import aiohttp
+import numpy
 from pandas import DataFrame, Series
 from sgqlc.operation import Operation
 from tqsdk.backtest import TqBacktest
 
-from tqsdk.datetime import _get_expire_rest_days
+from tqsdk.datetime import _get_expire_rest_days, _str_to_timestamp_nano
 from tqsdk.ins_schema import ins_schema, _add_all_frags
 from tqsdk.objs import Quote
 from tqsdk.diff import _get_obj
-from tqsdk.utils import _query_for_quote, _generate_uuid
+from tqsdk.utils import _generate_uuid
 from tqsdk.tafunc import _get_t_series, get_impv, _get_d1, get_delta, get_theta, get_gamma, get_vega, get_rho
 
 """
@@ -54,19 +54,8 @@ class QuoteList(list):
             if not hasattr(quote, '_task'):
                 quote._task = api.create_task(ensure_quote_with_underlying(api, quote), _caller_api=True)
 
-    async def _ensure_symbols(self):
-        if all([q.price_tick > 0 for q in self]):
-            return
-        query_symbols = [q._path[-1] for q in self if not q.price_tick > 0]
-        query_pack = _query_for_quote(query_symbols)
-        self._api._send_pack(query_pack)
-        async with self._api.register_update_notify(self) as update_chan:
-            async for _ in update_chan:
-                if all([q.price_tick > 0 for q in self]):
-                    return
-
     async def _ensure_quotes(self):
-        await self._ensure_symbols()
+        await self._api._ensure_symbol_async([q._path[-1] for q in self])
         self._api._auth._has_md_grants([q._path[-1] for q in self])  # 权限检查
         # 发送的请求会请求到所有字段，如果是期权也会请求标的的合约信息
         underlying_symbols = set([q.underlying_symbol for q in self if q.underlying_symbol])
@@ -126,13 +115,13 @@ class SymbolList(list):
         if query_result is None:
             await _query_graphql_async(self._api, self._query_id, self._query)
             query_result = symbols.get(self._query_id)
+            if isinstance(self._api._backtest, TqBacktest):  # 回测时，清空缓存的请求
+                self._api._send_pack({
+                    "aid": "ins_query",
+                    "query_id": self._query_id,
+                    "query": ""
+                })
         self += self._filter(query_result)
-        if isinstance(self._api._backtest, TqBacktest):  # 回测时，清空缓存的请求
-            self._api._send_pack({
-                "aid": "ins_query",
-                "query_id": self._query_id,
-                "query": ""
-            })
         return self
 
     def __await__(self):
@@ -164,16 +153,16 @@ class SymbolLevelList(namedtuple('SymbolLevel', ['in_money_options', 'at_money_o
         if query_result is None:
             await _query_graphql_async(self._api, self._query_id, self._query)
             query_result = symbols.get(self._query_id)
+            if isinstance(self._api._backtest, TqBacktest):  # 回测时，清空缓存的请求
+                self._api._send_pack({
+                    "aid": "ins_query",
+                    "query_id": self._query_id,
+                    "query": ""
+                })
         l0, l1, l2 = self._filter(query_result)
         self[0].extend(l0)
         self[1].extend(l1)
         self[2].extend(l2)
-        if isinstance(self._api._backtest, TqBacktest):  # 回测时，清空缓存的请求
-            self._api._send_pack({
-                "aid": "ins_query",
-                "query_id": self._query_id,
-                "query": ""
-            })
         return self
 
     def __await__(self):
@@ -197,6 +186,18 @@ class TqDataFrame(DataFrame):
         return self.__dict__["_task"].__await__()
 
 
+def _get_col_dtype(col):
+    if col == "expired":
+        return bool
+    if col in [
+        "price_tick", "volume_multiple", "strike_price", "upper_limit", "lower_limit", "pre_settlement", "pre_close",
+        "pre_open_interest", "max_limit_order_volume", "max_market_order_volume", "expire_datetime", "expire_rest_days",
+        "delivery_year", "delivery_month", "last_exercise_datetime", "exercise_year", "exercise_month",
+    ]:
+        return float
+    return object
+
+
 class TqSymbolDataFrame(DataFrame):
 
     def __init__(self, api, symbol_list, backtest_timestamp, *args, **kwargs):
@@ -261,7 +262,7 @@ class TqSymbolDataFrame(DataFrame):
                     self._quotes_to_dataframe(quotes)
                     if self.__dict__["_backtest_timestamp"]:
                         # 回测时这些字段应该为 nan
-                        self.loc[:, ["upper_limit", "lower_limit", "pre_settlement", "pre_open_interest", "pre_close"]] = float('nan')
+                        self.loc[:, ["upper_limit", "lower_limit", "pre_settlement", "pre_open_interest", "pre_close"]] = numpy.nan
                         # 回测时清空请求，不缓存请求内容
                         self.__dict__["_api"]._send_pack({
                             "aid": "ins_query",
@@ -279,14 +280,108 @@ class TqSymbolDataFrame(DataFrame):
         for col in self.__dict__["_columns"]:
             if col == "expire_rest_days":
                 current_dt = self._api._get_current_datetime().timestamp()
-                self.loc[:, col] = [_get_expire_rest_days(quotes[s]['expire_datetime'], current_dt)
+                self[col] = [_get_expire_rest_days(quotes[s]['expire_datetime'], current_dt)
                                     if quotes[s].get('expire_datetime') else float('nan')
                                     for s in self.__dict__["_symbol_list"]]
             elif col == "trading_time_day" or col == "trading_time_night":
                 k = 'day' if col == "trading_time_day" else 'night'
-                self.loc[:, col] = Series([self._get_trading_time(quotes, s, k) for s in self.__dict__["_symbol_list"]])
+                self[col] = Series(
+                    [self._get_trading_time(quotes, s, k) for s in self.__dict__["_symbol_list"]],
+                    dtype=_get_col_dtype(col)
+                )
             else:
-                self.loc[:, col] = Series([quotes[s].get(col, default_quote[col]) for s in self.__dict__["_symbol_list"]])
+                self[col] = Series(
+                    [quotes[s].get(col, default_quote[col]) for s in self.__dict__["_symbol_list"]],
+                    dtype=_get_col_dtype(col)
+                )
+
+    def __await__(self):
+        return self.__dict__["_task"].__await__()
+
+
+class TqMdSettlementDataFrame(DataFrame):
+
+    def __init__(self, api, symbol, days, start_dt):
+        self.__dict__["_api"] = api
+        params = {'days': days, 'symbols': symbol if isinstance(symbol, str) else ",".join(symbol)}
+        if start_dt is not None:
+            params['start_date'] = start_dt.strftime("%Y%m%d")
+        else:
+            params['days'] += 1
+        self.__dict__["_params"] = params
+        self.__dict__["_days"] = days
+        self.__dict__["_symbol"] = symbol
+        self.__dict__["_columns"] = [
+            "datetime",
+            "symbol",
+            "settlement"
+        ]
+        super(TqMdSettlementDataFrame, self).__init__(data=[], columns=self.__dict__["_columns"])
+        self.__dict__["_task"] = api.create_task(self.async_update(), _caller_api=True)
+
+    async def _get_settlement_data(self, settlement_id):
+        # 下载结算价数据，并将数据发回到 api.recv_chan
+        async with aiohttp.ClientSession(headers=self.__dict__["_api"]._base_headers) as session:
+            url = "https://md-settlement-system-fc-api.shinnytech.com/mss"
+            async with session.get(url, params=self.__dict__["_params"]) as response:
+                response.raise_for_status()
+                content = await response.json()
+                await self.__dict__["_api"]._ws_md_recv_chan.send({
+                    "aid": "rtn_data",
+                    "data": [{
+                        "_settlement": {
+                            settlement_id: content
+                        },
+                        "_settlement_finished": {
+                            settlement_id: True
+                        }
+                    }]
+                })
+
+    async def async_update(self):
+        await self.__dict__["_api"]._ensure_symbol_async(self.__dict__["_symbol"])
+        settlement_id = _generate_uuid("PYSDK_settlement")
+        self.__dict__["_api"].create_task(self._get_settlement_data(settlement_id), _caller_api=True)  # 错误会抛给 api 处理
+        settlement_finished = _get_obj(self.__dict__["_api"]._data, ["_settlement_finished"])
+        async with self.__dict__["_api"].register_update_notify(settlement_finished) as update_chan:
+            async for _ in update_chan:
+                if not settlement_finished.get(settlement_id, False):
+                    continue
+                content = self.__dict__["_api"]._data.get("_settlement", {}).get(settlement_id, {})
+                data = self._content_to_list(content)
+                for i, d in enumerate(data):
+                    self.loc[i] = d
+                self.sort_values(by=['datetime', 'symbol'], inplace=True, ignore_index=True)
+                # 读完数据，清空数据
+                await self.__dict__["_api"]._ws_md_recv_chan.send({
+                    "aid": "rtn_data",
+                    "data": [{
+                        "_settlement": {
+                            settlement_id: None
+                        },
+                        "_settlement_finished": {
+                            settlement_id: None
+                        }
+                    }]
+                })
+                return self
+
+
+    def _content_to_list(self, content):
+        sorted_content = sorted(
+            content.items(),
+            key=lambda item: item[0],
+            reverse=True
+        )
+        # 取最近的 N 天数据
+        days = self.__dict__["_days"]
+        recent_content = sorted_content[:days]
+        return [
+            {"datetime": dt, "symbol": symbol, "settlement": settlement}
+            for dt, symbols in recent_content
+            for symbol, settlement in symbols.items()
+            if settlement is not None 
+        ]
 
     def __await__(self):
         return self.__dict__["_task"].__await__()
@@ -337,19 +432,23 @@ class TqSymbolRankingDataFrame(DataFrame):
                     "data": [{
                         "_symbol_rankings": {
                             ranking_id: content
+                        },
+                        "_symbol_rankings_finished": {
+                            ranking_id: True
                         }
                     }]
                 })
 
     async def async_update(self):
+        await self.__dict__["_api"]._ensure_symbol_async(self.__dict__["_symbol"])
         ranking_id = _generate_uuid("PYSDK_rank")
         self.__dict__["_api"].create_task(self._get_ranking_data(ranking_id), _caller_api=True)  # 错误会抛给 api 处理
-        symbol_rankings = _get_obj(self.__dict__["_api"]._data, ["_symbol_rankings"])
-        async with self.__dict__["_api"].register_update_notify(symbol_rankings) as update_chan:
+        symbol_rankings_finished = _get_obj(self.__dict__["_api"]._data, ["_symbol_rankings_finished"])
+        async with self.__dict__["_api"].register_update_notify(symbol_rankings_finished) as update_chan:
             async for _ in update_chan:
-                content = symbol_rankings.get(ranking_id, None)
-                if content is None:
+                if not symbol_rankings_finished.get(ranking_id, False):
                     continue
+                content = self.__dict__["_api"]._data.get("_symbol_rankings", {}).get(ranking_id, {})
                 data = self._content_to_list(content)
                 for i, d in enumerate(data):
                     self.loc[i] = d
@@ -361,6 +460,9 @@ class TqSymbolRankingDataFrame(DataFrame):
                     "data": [{
                         "_symbol_rankings": {
                             ranking_id: None
+                        },
+                        "_symbol_rankings_finished": {
+                            ranking_id: None
                         }
                     }]
                 })
@@ -450,7 +552,7 @@ class TqOptionGreeksDataFrame(DataFrame):
         series_close = Series(data=[q.last_price for q in quotes])  # 期权最新价
         series_close1 = Series(data=[q.underlying_quote.last_price for q in quotes])  # 标的最新价
         series_o = Series(data=[q.option_class for q in quotes])
-        series_datetime = Series(data=[datetime.strptime(q.datetime, "%Y-%m-%d %H:%M:%S.%f").timestamp() * 1000000000 for q in quotes])
+        series_datetime = Series(data=[_str_to_timestamp_nano(q.datetime) for q in quotes])
         series_expire_datetime = Series(data=[q.expire_datetime for q in quotes])
         series_t = _get_t_series(series_datetime, 0, series_expire_datetime)  # 到期时间
         if self.__dict__["_v_list"] is None:
