@@ -14,22 +14,11 @@ import math
 from typing import Union
 
 import numpy as np
-try:
-    import pandas as pd
-except ImportError as e:
-    err_msg = f"执行 import pandas 时发生错误： {e}。\n"
-    err_msg += """
-    当遇到此问题时，如果您是 windows 用户，并且安装的 pandas 版本大于等于 1.0.2，可以尝试以下解决方案之一，再重新运行程序即可。
-    （您使用的机器缺少 pandas 需要的运行时环境）
-    1. 到微软官网下载您机器上安装 python 对应版本的 vc_redist 文件运行安装即可。https://www.microsoft.com/en-us/download/details.aspx?id=48145 
-       vc_redist.x64.exe（64 位 python）、 vc_redist.x86.exe（32 位 python）
-    2. 卸载当前的 pandas (pip uninstall pandas)
-       安装 pandas 1.0.1 版本 (pip install pandas==1.0.1)
-    """
-    raise Exception(err_msg)
+import pandas as pd
 from scipy import stats
 
-from tqsdk.datetime import _get_period_timestamp
+from tqsdk.datetime import _get_period_timestamp, _str_to_timestamp_nano, _datetime_to_timestamp_nano, \
+    _timestamp_nano_to_datetime, _timestamp_nano_to_str
 
 
 def ref(series, n):
@@ -50,7 +39,7 @@ def ref(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         pre_close = tafunc.ref(klines.close, 1)  # 将收盘价序列右移一位, 得到昨收盘序列
         change = klines.close - pre_close        # 收盘价序列 - 昨收盘序列, 得到涨跌序列
@@ -78,7 +67,7 @@ def std(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         std = tafunc.std(klines.close, 5)  # 收盘价序列每5项计算一个标准差
         print(list(std))
@@ -110,7 +99,7 @@ def ma(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         ma = tafunc.ma(klines.close, 5)
         print(list(ma))
@@ -142,7 +131,7 @@ def sma(series, n, m):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         sma = tafunc.sma(klines.close, 5, 2)  # 收盘价序列每5项计算一个扩展指数加权移动平均值
         print(list(sma))
@@ -174,7 +163,7 @@ def ema(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         ema = tafunc.ema(klines.close, 5)
         print(list(ema))
@@ -204,7 +193,7 @@ def ema2(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         ema2 = tafunc.ema2(klines.close, 5)  # 求收盘价在5个周期的线性加权移动平均值
         print(list(ema2))
@@ -234,7 +223,7 @@ def crossup(a, b):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         crossup = tafunc.crossup(tafunc.ma(klines.close, 5), tafunc.ma(klines.close, 10))
         print(list(crossup))
@@ -259,7 +248,7 @@ def crossdown(a, b):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
         
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         crossdown = tafunc.crossdown(tafunc.ma(klines.close, 5), tafunc.ma(klines.close, 10))
         print(list(crossdown))
@@ -286,7 +275,7 @@ def count(cond, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         # 统计从申请到的行情数据以来到当前这段时间内, 5周期均线上穿10周期均线的次数:
         count = tafunc.count(tafunc.crossup(tafunc.ma(klines.close, 5), tafunc.ma(klines.close, 10)), 0)
@@ -320,7 +309,7 @@ def trma(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         trma = tafunc.trma(klines.close, 10)
         print(list(trma))
@@ -358,7 +347,7 @@ def harmean(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         harmean = tafunc.harmean(klines.close, 5)  # 求5周期收盘价的调和平均值
         print(list(harmean))
@@ -390,7 +379,7 @@ def numpow(series, n, m):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         numpow = tafunc.numpow(klines.close, 5, 2)
         print(list(numpow))
@@ -415,7 +404,7 @@ def abs(series):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         abs = tafunc.abs(klines.close)
         print(list(abs))
@@ -440,7 +429,7 @@ def min(series1, series2):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         min = tafunc.min(klines.close, klines.open)
         print(list(min))
@@ -465,7 +454,7 @@ def max(series1, series2):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         max = tafunc.max(klines.close, klines.open)
         print(list(max))
@@ -520,7 +509,7 @@ def exist(cond, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         # 判断4个周期中是否存在收盘价大于前一个周期的最高价, 存在返回1, 不存在则返回0
         exist = tafunc.exist(klines.close > klines.high.shift(1), 4)
@@ -546,7 +535,7 @@ def every(cond, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         # 判断在4周期内, 3周期的简单移动平均是否一直大于5周期的简单移动平均
         every = tafunc.every(tafunc.ma(klines.close, 3) > tafunc.ma(klines.close, 5), 4)
@@ -574,7 +563,7 @@ def hhv(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         hhv = tafunc.hhv(klines.high, 4)  # 求4个周期最高价的最大值, 即4周期高点(包含当前k线)
         print(list(hhv))
@@ -601,7 +590,7 @@ def llv(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         llv = tafunc.llv(klines.low, 5)  # 求5根k线最低点(包含当前k线)
         print(list(llv))
@@ -634,7 +623,7 @@ def avedev(series, n):
 
         from tqsdk import TqApi, TqAuth, TqSim, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1908", 24 * 60 * 60)
         # 计算收盘价在5周期内的平均绝对偏差, 表示5个周期内每个周期的收盘价与5周期收盘价的平均值的差的绝对值的平均值, 判断收盘价与其均值的偏离程度:
         avedev = tafunc.avedev(klines.close, 5)
@@ -671,14 +660,10 @@ def _to_ns_timestamp(input_time):
             return int(input_time)
         else:  # 秒
             return int(input_time * 1e9)
-
     elif isinstance(input_time, str):  # str 类型时间
-        d = datetime.datetime.strptime(input_time, "%Y-%m-%d %H:%M:%S.%f")
-        d = int(d.timestamp() * 1e9)
-        return d
+        return _str_to_timestamp_nano(input_time)
     elif isinstance(input_time, datetime.datetime):  # datetime 类型时间
-        d = int(input_time.timestamp() * 1e9)
-        return d
+        return _datetime_to_timestamp_nano(input_time)
     else:
         raise TypeError("暂不支持此类型的转换")
 
@@ -761,11 +746,8 @@ def time_to_str(input_time):
         print(time_to_str(datetime.datetime(2019, 10, 14, 14, 26, 1)))  # 将datetime.datetime时间转为%Y-%m-%d %H:%M:%S.%f 格式的str类型时间
     """
     # 转为秒级时间戳
-    ts = _to_ns_timestamp(input_time) / 1e9
-    # 转为 %Y-%m-%d %H:%M:%S.%f 格式的 str 类型时间
-    dt = datetime.datetime.fromtimestamp(ts)
-    dt = dt.strftime('%Y-%m-%d %H:%M:%S.%f')
-    return dt
+    ts = _to_ns_timestamp(input_time)
+    return _timestamp_nano_to_str(ts)
 
 
 def time_to_datetime(input_time):
@@ -792,10 +774,8 @@ def time_to_datetime(input_time):
         print(time_to_datetime("2019-10-14 14:26:01.000000"))  # 将%Y-%m-%d %H:%M:%S.%f 格式的str类型时间转为datetime.datetime时间
     """
     # 转为秒级时间戳
-    ts = _to_ns_timestamp(input_time) / 1e9
-    # 转为datetime.datetime类型
-    dt = datetime.datetime.fromtimestamp(ts)
-    return dt
+    ts = _to_ns_timestamp(input_time)
+    return _timestamp_nano_to_datetime(ts)
 
 
 def barlast(cond):
@@ -816,7 +796,7 @@ def barlast(cond):
         from tqsdk import TqApi, TqAuth
         from tqsdk.tafunc import barlast
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         klines = api.get_kline_serial("SHFE.cu1912", 60)
         # print(list(klines.close))
         # print(list(klines.open))
@@ -828,7 +808,7 @@ def barlast(cond):
 
     """
     cond = cond.to_numpy()
-    v = np.array(~cond, dtype=np.int)
+    v = np.array(~cond, dtype=int)
     c = np.cumsum(v)
     x = c[cond]
     d = np.diff(np.concatenate(([0], x)))
@@ -840,7 +820,27 @@ def barlast(cond):
     return pd.Series(r)
 
 
-def _get_t_series(series: pd.Series, dur: int, expire_datetime: int):
+def _duration_ensure_unit_to_s(dur: Union[int, pd.Series]) -> int:
+    """
+    判断输入duration这一时间的单位。如果单位是纳秒，则转换为秒。
+
+    Args:
+        dur: Union[int, pd.Series]: 数据周期
+             可能是一个可以直接判断的int，也可能是Dataframe中的某一列
+
+    Returns:
+        int: 以秒为单位的数据周期
+    """
+    if isinstance(dur, pd.Series):
+        # 进行类型转换，确保运算过程不报错
+        dur = dur[0]
+    if dur % (10 ** 9) == 0:
+        dur //= (10 ** 9)
+    return dur
+
+
+def _get_t_series(series: pd.Series, dur: Union[int, pd.Series], expire_datetime: int):
+    dur = _duration_ensure_unit_to_s(dur)
     t = pd.Series(pd.to_timedelta(expire_datetime - (series / 1e9 + dur), unit='s'))
     return (t.dt.days * 86400 + t.dt.seconds) / (360 * 86400)
 
@@ -852,12 +852,12 @@ def _get_d1(series: pd.Series, k: float, r: float, v: Union[float, pd.Series], t
 
 def _get_cdf(series: pd.Series):
     s = series.loc[series.notna()]
-    return series.loc[series.isna()].append(pd.Series(stats.norm.cdf(s), index=s.index), verify_integrity=True)
+    return pd.concat([series.loc[series.isna()], pd.Series(stats.norm.cdf(s), index=s.index)], verify_integrity=True)
 
 
 def _get_pdf(series: pd.Series):
     s = series.loc[series.notna()]
-    return series.loc[series.isna()].append(pd.Series(stats.norm.pdf(s), index=s.index), verify_integrity=True)
+    return pd.concat([series.loc[series.isna()], pd.Series(stats.norm.pdf(s), index=s.index)], verify_integrity=True)
 
 
 def _get_options_class(series: pd.Series, option_class: Union[str, pd.Series]):
@@ -895,7 +895,7 @@ def get_t(df, expire_datetime):
 
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote('SHFE.cu2006C45000')
         klines = api.get_kline_serial(['SHFE.cu2006C45000', 'SHFE.cu2006'], 24 * 60 * 60, 50)
         t = tafunc.get_t(klines, quote.expire_datetime)
@@ -921,7 +921,7 @@ def get_his_volatility(df, quote):
 
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote('SHFE.cu2006')
         klines = api.get_kline_serial('SHFE.cu2006', 24 * 60 * 60, 50)
         v = tafunc.get_his_volatility(klines, quote)
@@ -941,7 +941,7 @@ def _get_volatility(series: pd.Series, dur: Union[pd.Series, int] = 86400, tradi
     if series_u.size < 2:  # 自由度小于2无法计算，返回一个默认值
         return float("nan")
     seconds_per_day = 24 * 60 * 60
-    dur = dur[0] if isinstance(dur, pd.Series) else dur
+    dur = _duration_ensure_unit_to_s(dur)
     if dur < 24 * 60 * 60 and trading_time:
         periods = _get_period_timestamp(0, trading_time.get("day", []) + trading_time.get("night", []))
         seconds_per_day = sum([p[1] - p[0] for p in periods]) / 1e9
@@ -985,7 +985,7 @@ def get_bs_price(series, k, r, v, t, option_class):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1044,7 +1044,7 @@ def get_delta(series, k, r, v, t, option_class, d1=None):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1098,7 +1098,7 @@ def get_gamma(series, k, r, v, t, d1=None):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1157,7 +1157,7 @@ def get_theta(series, k, r, v, t, option_class, d1=None):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1213,7 +1213,7 @@ def get_vega(series, k, r, v, t, d1=None):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1272,7 +1272,7 @@ def get_rho(series, k, r, v, t, option_class, d1=None):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1333,7 +1333,7 @@ def get_impv(series, series_option, k, r, init_v, t, option_class):
         import pandas as pd
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006")
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 10)
         v = tafunc.get_his_volatility(ks, quote)  # 历史波动率
@@ -1375,7 +1375,7 @@ def get_ticks_info(df):
 
         from tqsdk import TqApi, TqAuth, tafunc
 
-        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        api = TqApi(auth=TqAuth("快期账户", "账户密码"))
         ticks = api.get_tick_serial('SHFE.cu2006', 100)
         ticksinfo = tafunc.get_ticks_info(ticks)
         for i, v in ticksinfo.items():
@@ -1424,14 +1424,12 @@ def get_dividend_df(stock_dividend_ratio, cash_dividend_ratio):
     """
     # 除权矩阵
     stock_dividend_df = pd.DataFrame({
-        "datetime": [datetime.datetime.strptime(s.split(",")[0], "%Y%m%d").timestamp() * 1e9 for s in
-                     stock_dividend_ratio],
+        "datetime": [_str_to_timestamp_nano(s.split(",")[0], fmt="%Y%m%d") for s in stock_dividend_ratio],
         "stock_dividend": np.array([float(s.split(",")[1]) for s in stock_dividend_ratio])
     })
     # 除息矩阵
     cash_dividend_df = pd.DataFrame({
-        "datetime": [datetime.datetime.strptime(s.split(",")[0], "%Y%m%d").timestamp() * 1e9 for s in
-                     cash_dividend_ratio],
+        "datetime": [_str_to_timestamp_nano(s.split(",")[0], fmt="%Y%m%d") for s in cash_dividend_ratio],
         "cash_dividend": [float(s.split(",")[1]) for s in cash_dividend_ratio]
     })
     # 除权除息矩阵
@@ -1470,7 +1468,7 @@ def get_dividend_factor(dividend_df, last_item, item):
 def _tq_pstdev(data: Series, mu: float):
     """
     计算标准差
-    标准库提供的方法 statistics.pstdev 在 py3.6,py3.7 版本下参数 mean 不能设定为指定值，所以这里另外计算。
+    标准库提供的方法 statistics.pstdev 在 py3.7 版本下参数 mean 不能设定为指定值，所以这里另外计算。
     """
     n = data.shape[0]
     assert n >= 1
@@ -1553,4 +1551,3 @@ def _cum_counts(s: Series):
     output: [0, 0, 1, 0, 1, 0, 1, 0, 0, 1, 2, 0, 1, 0, 0, 1, 2, 3, 4, 0, 1, 2, 3, 4, 5, 0, 1, 2, 3, 0, 0]
     """
     return s * (s.groupby((s != s.shift()).cumsum()).cumcount() + 1)
-
