@@ -6,17 +6,16 @@ import asyncio
 import csv
 import os
 from datetime import date, datetime
-from typing import Union, List
+from encodings.utf_8 import StreamWriter
+from typing import Union, List, Optional
 import lzma
 
 import pandas
 
 from tqsdk.api import TqApi
-from tqsdk.channel import TqChan
-from tqsdk.datetime import _get_trading_day_start_time, _get_trading_day_end_time
+from tqsdk.datetime import _cst_tz, _convert_user_input_to_nano
 from tqsdk.diff import _get_obj
-from tqsdk.tafunc import get_dividend_df, get_dividend_factor
-from tqsdk.utils import _generate_uuid
+from tqsdk.utils import _generate_uuid, _get_dividend_factor
 
 try:
     file_path = os.path.split(os.path.abspath(__file__))[0]
@@ -34,7 +33,7 @@ class DataDownloader:
     """
     数据下载工具是 TqSdk 专业版中的功能，能让用户下载目前 TqSdk 提供的全部期货、期权和股票类的历史数据，下载数据支持 tick 级别精度和任意 kline 周期
 
-    如果想使用数据下载工具，可以点击 `天勤量化专业版 <https://www.shinnytech.com/tqsdk_professional/>`_ 申请使用或购买
+    如果想使用数据下载工具，可以点击 `天勤量化专业版 <https://www.shinnytech.com/tqsdk-buy/>`_ 申请使用或购买
 
     历史数据下载器, 输出到csv文件
 
@@ -42,7 +41,8 @@ class DataDownloader:
     """
 
     def __init__(self, api: TqApi, symbol_list: Union[str, List[str]], dur_sec: int, start_dt: Union[date, datetime],
-                 end_dt: Union[date, datetime], csv_file_name: str, adj_type: Union[str, None] = None) -> None:
+                 end_dt: Union[date, datetime], csv_file_name: Union[str, asyncio.StreamWriter], write_mode: str = "w",
+                 adj_type: Union[str, None] = None) -> None:
         """
         创建历史数据下载器实例
 
@@ -53,11 +53,22 @@ class DataDownloader:
 
             dur_sec (int): 数据周期，以秒为单位。例如: 1分钟线为60,1小时线为3600,日线为86400,Tick数据为0
 
-            start_dt (date/datetime): 起始时间, 如果类型为 date 则指的是交易日, 如果为 datetime 则指的是具体时间点
+            start_dt (date/datetime): 起始时间
+                * date: 指的是交易日
 
-            end_dt (date/datetime): 结束时间, 如果类型为 date 则指的是交易日, 如果为 datetime 则指的是具体时间点
+                * datetime: 指的是具体时间点，如果没有指定时区信息，则默认为北京时间
 
-            csv_file_name (str): 输出 csv 的文件名
+            end_dt (date/datetime): 结束时间
+                * date: 指的是交易日
+
+                * datetime: 指的是具体时间点，如果没有指定时区信息，则默认为北京时间
+
+            csv_file_name (str/StreamWriter): [必填]输出方式:
+                * str : 输出 csv 的文件名
+
+                * StreamWriter: 直接将内容输出到 StreamWriter
+
+            write_mode (str): 写入模式，默认值为 "w"。"w" 表示覆盖写入，会写入标题行，再写入数据；"a" 表示追加写入，不写标题行，直接写入数据。
 
             adj_type (str/None): 复权计算方式，默认值为 None。"F" 为前复权；"B" 为后复权；None 表示不复权。只对股票、基金合约有效。
 
@@ -68,7 +79,7 @@ class DataDownloader:
             from tqsdk import TqApi, TqAuth, TqSim
             from tqsdk.tools import DataDownloader
 
-            api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+            api = TqApi(auth=TqAuth("快期账户", "账户密码"))
             download_tasks = {}
             # 下载从 2018-01-01 到 2018-09-01 的 SR901 日线数据
             download_tasks["SR_daily"] = DataDownloader(api, symbol_list="CZCE.SR901", dur_sec=24*60*60,
@@ -92,15 +103,8 @@ class DataDownloader:
         """
         self._api = api
         if not self._api._auth._has_feature("tq_dl"):
-            raise Exception("您的账户不支持下载历史数据功能，需要购买专业版本后使用。升级网址：https://account.shinnytech.com")
-        if isinstance(start_dt, datetime):
-            self._start_dt_nano = int(start_dt.timestamp() * 1e9)
-        else:
-            self._start_dt_nano = _get_trading_day_start_time(int(datetime(start_dt.year, start_dt.month, start_dt.day).timestamp()) * 1000000000)
-        if isinstance(end_dt, datetime):
-            self._end_dt_nano = int(end_dt.timestamp() * 1e9)
-        else:
-            self._end_dt_nano = _get_trading_day_end_time(int(datetime(end_dt.year, end_dt.month, end_dt.day).timestamp()) * 1000000000)
+            raise Exception("您的账户不支持下载历史数据功能，需要购买后才能使用。升级网址：https://www.shinnytech.com/tqsdk-buy/")
+        self._start_dt_nano, self._end_dt_nano = _convert_user_input_to_nano(start_dt, end_dt)
         self._current_dt_nano = self._start_dt_nano
         self._symbol_list = symbol_list if isinstance(symbol_list, list) else [symbol_list]
         # 下载合约超时时间（默认 30s），已下市的没有交易的合约，超时时间可以设置短一点（2s），用户不希望自己的程序因为没有下载到数据而中断
@@ -111,9 +115,17 @@ class DataDownloader:
         if adj_type not in [None, "F", "B", "FORWARD", "BACK"]:
             raise Exception("adj_type 参数只支持 None (不复权) ｜ 'F' (前复权) ｜ 'B' (后复权)")
         self._adj_type = adj_type[0] if adj_type else adj_type
-        self._csv_file_name = csv_file_name
+        if isinstance(csv_file_name, str) or isinstance(csv_file_name, asyncio.StreamWriter):
+            self._csv_file_name = csv_file_name
+        else:
+            raise Exception("csv_file_name 参数只支持 str ｜ StreamWriter 类型")
+        if write_mode not in ["w", "a"]:
+            raise Exception("write_mode 参数只支持 'w' ｜ 'a'")
+        self._write_mode = write_mode
         self._csv_header = self._get_headers()
-        self._dividend_cache = {}  # 缓存合约对应的复权系数矩阵，每个合约只计算一次
+        # 缓存合约对应的复权系数矩阵，每个合约只计算一次
+        # 含义为截止 datetime 之前(不包含) 应使用 factor 复权
+        self._dividend_cache = {}
         self._data_series = None
         self._task = self._api.create_task(self._run())
 
@@ -136,7 +148,7 @@ class DataDownloader:
         return 100.0 if self._task.done() else (self._current_dt_nano - self._start_dt_nano) / (
                 self._end_dt_nano - self._start_dt_nano) * 100
 
-    def _get_data_series(self) -> pandas.DataFrame:
+    def _get_data_series(self) -> Optional[pandas.DataFrame]:
         """
         获取下载的 DataFrame 格式数据
 
@@ -153,7 +165,7 @@ class DataDownloader:
             from contextlib import closing
             from tqsdk.tools import DataDownloader
 
-            api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+            api = TqApi(auth=TqAuth("快期账户", "账户密码"))
             # 下载从 2018-06-01 到 2018-09-01 的 SR901 日线数据
             download_task = DataDownloader(api, symbol_list="CZCE.SR901", dur_sec=24*60*60,
                                 start_dt=date(2018, 6, 1), end_dt=date(2018, 9, 1), csv_file_name="klines.csv")
@@ -166,67 +178,46 @@ class DataDownloader:
         """
         if not self._task.done():
             return None
-        if not self._data_series:
-            self._data_series = pandas.read_csv(self._csv_file_name)
-        return self._data_series
+        if isinstance(self._csv_file_name, str):
+            if not self._data_series:
+                self._data_series = pandas.read_csv(self._csv_file_name)
+            return self._data_series
+        else:
+            raise Exception('DataDownloader._get_data_series 接口仅支持 csv_file_name 參數为 str 时使用')
 
-    async def _update_dividend_factor(self):
-        for s in self._dividend_cache:
-            # 对每个除权除息矩阵增加 factor 序列，为当日的复权因子
-            df = self._dividend_cache[s]["df"]
-            df["pre_close"] = float('nan')  # 初始化 pre_close 为 nan
-            between = df["datetime"].between(self._start_dt_nano, self._end_dt_nano)  # 只需要开始时间～结束时间之间的复权因子
-            for i in df[between].index:
-                chart_info = {
-                    "aid": "set_chart",
-                    "chart_id": _generate_uuid("PYSDK_downloader"),
-                    "ins_list": s,
-                    "duration": 86400 * 1000000000,
-                    "view_width": 2,
-                    "focus_datetime": int(df.iloc[i].datetime),
-                    "focus_position": 1
-                }
-                await self._api._send_chan.send(chart_info)
-                chart = _get_obj(self._api._data, ["charts", chart_info["chart_id"]])
-                serial = _get_obj(self._api._data, ["klines", s, str(86400000000000)])
-                try:
-                    async with self._api.register_update_notify() as update_chan:
-                        async for _ in update_chan:
-                            if not (chart_info.items() <= _get_obj(chart, ["state"]).items()):
-                                continue  # 当前请求还没收齐回应, 不应继续处理
-                            left_id = chart.get("left_id", -1)
-                            right_id = chart.get("right_id", -1)
-                            if (left_id == -1 and right_id == -1) or self._api._data.get("mdhis_more_data", True) or serial.get("last_id", -1) == -1:
-                                continue  # 定位信息还没收到, 或数据序列还没收到, 合约的数据是否收到
-                            last_item = serial["data"].get(str(left_id), {})
-                            # 复权时间点的昨收盘
-                            df.loc[i, 'pre_close'] = last_item['close'] if last_item.get('close') else float('nan')
-                            break
-                finally:
-                    await self._api._send_chan.send({
-                        "aid": "set_chart",
-                        "chart_id": chart_info["chart_id"],
-                        "ins_list": "",
-                        "duration": 86400000000000,
-                        "view_width": 2
-                    })
-            df["factor"] = (df["pre_close"] - df["cash_dividend"]) / df["pre_close"] / (1 + df["stock_dividend"])
-            df["factor"].fillna(1, inplace=True)
+    async def _ensure_dividend_factor(self, quote, timestamp):
+        if quote.instrument_id not in self._dividend_cache:
+            df = await _get_dividend_factor(self._api, quote, timestamp, self._end_dt_nano, chart_id_prefix="PYSDK_downloader")
+            # 插入结束时间这条记录, 因为可能存在行情时间等于 _end_dt_nano 的行情，因此这里 +1
+            new_row = pandas.DataFrame([{
+                "datetime": self._end_dt_nano+1, 
+                "stock_dividend": 0.0,
+                "cash_dividend": 0.0, 
+                "pre_close": float('nan'),
+                "factor": 1.0
+            }])
+            df = pandas.concat([df, new_row], ignore_index=True)
+            if self._adj_type == "F":
+                df["factor"] = df["factor"].iloc[::-1].cumprod().iloc[::-1]
+            elif self._adj_type == "B":
+                # 后复权按定义上应该从第一笔行情之后产生的复权事件开始
+                # 第一笔行情时间一定小于 df["datetime"].iloc[0], 因此复权是从 df["datetime"].iloc[0] 开始
+                df["factor"] = 1.0 / df["factor"].cumprod()
+                # 至此 df 每行的含义为从 datetime 开始应使用 factor 复权
+                # 该格式并不好用，需要改为截止 datetime 之前(不包含) 应使用 factor 复权
+                shifted_factor = df["factor"].shift(1)
+                shifted_factor.iloc[0] = 1.0
+                df["factor"] = shifted_factor
+            self._dividend_cache[quote.instrument_id] = {
+                "df": df,
+                "last_dt": 0,
+                "factor": float("nan"),
+            }
 
     async def _run(self):
         self._quote_list = await self._api.get_quote_list(self._symbol_list)
-        # 如果存在 STOCK / FUND 并且 adj_type is not None, 这里需要提前准备下载时间段内的复权因子
-        if self._adj_type:
-            for quote in self._quote_list:
-                if quote.ins_class in ["STOCK", "FUND"]:
-                    self._dividend_cache[quote.instrument_id] = {
-                        "df": get_dividend_df(quote.stock_dividend_ratio, quote.cash_dividend_ratio),
-                        "back_factor": 1.0
-                    }
-        # 前复权需要提前计算除权因子
-        await self._update_dividend_factor()
-        self._data_chan = TqChan(self._api)
-        task = self._api.create_task(self._download_data())
+        # 下载数据的 async generator
+        gen = self._download_data()
         # cols 是复权需要重新计算的列名
         index_datetime_nano = self._csv_header.index("datetime_nano")
         if self._dur_nano != 0:
@@ -235,42 +226,44 @@ class DataDownloader:
             cols = ["last_price", "highest", "lowest"]
             cols.extend(f"{x}{i}" for x in ["bid_price", "ask_price"] for i in range(1, 6))
         try:
-            with open(self._csv_file_name, 'w', newline='') as csvfile:
-                csv_writer = csv.writer(csvfile, dialect='excel')
+            if isinstance(self._csv_file_name, asyncio.StreamWriter):
+                writer = StreamWriter(self._csv_file_name)
+            else:
+                writer = open(self._csv_file_name, self._write_mode, newline='')
+            csv_writer = csv.writer(writer, dialect='excel')
+            if self._write_mode == "w":
                 csv_writer.writerow(self._csv_header)
-                last_dt = None
-                async for item in self._data_chan:
-                    for quote in self._quote_list:
-                        symbol = quote.instrument_id
-                        if self._adj_type and quote.ins_class in ["STOCK", "FUND"]:
-                            dividend_df = self._dividend_cache[symbol]["df"]
-                            factor = 1
-                            if self._adj_type == "F":
-                                gt = dividend_df["datetime"].gt(item[index_datetime_nano])
-                                if gt.any():
-                                    factor = dividend_df[gt]["factor"].cumprod().iloc[-1]
-                            elif self._adj_type == "B" and last_dt:
-                                gt = dividend_df['datetime'].gt(last_dt)
-                                if gt.any():
-                                    index = dividend_df[gt].index[0]
-                                    if item[index_datetime_nano] >= dividend_df.loc[index, 'datetime']:
-                                        self._dividend_cache[symbol]["back_factor"] *= (1 / dividend_df[gt].loc[index, 'factor'])
-                                factor = self._dividend_cache[symbol]["back_factor"]
-                            last_dt = item[index_datetime_nano]
-                            if factor != 1:
-                                item = item.copy()
-                                for c in cols:  # datetime_nano
-                                    index = self._csv_header.index(f"{symbol}.{c}")
-                                    item[index] = item[index] * factor
-                    csv_writer.writerow(item)
+            async for item in gen:
+                for quote in self._quote_list:
+                    symbol = quote.instrument_id
+                    if self._adj_type and quote.ins_class in ["STOCK", "FUND"]:
+                        # 如果存在 STOCK / FUND 并且 adj_type is not None, 这里需要提前准备下载时间段内的复权因子
+                        # 前复权需要提前计算除权因子
+                        await self._ensure_dividend_factor(quote, item[index_datetime_nano])
+                        dividend_cache = self._dividend_cache[symbol]
+                        # dividend_df 和 _data_chan 中取出的数据都是按时间升序排列的，因此可以使用归并算法
+                        if dividend_cache["last_dt"] <= item[index_datetime_nano]:
+                            dividend_df = dividend_cache["df"]
+                            dividend_df = dividend_df[dividend_df["datetime"].gt(item[index_datetime_nano])]
+                            dividend_cache["df"] = dividend_df
+                            dividend_cache["last_dt"] = dividend_df["datetime"].iloc[0]
+                            dividend_cache["factor"] = dividend_df["factor"].iloc[0]
+                        if dividend_cache["factor"] != 1:
+                            item = item.copy()
+                            for c in cols:  # datetime_nano
+                                index = self._csv_header.index(f"{symbol}.{c}")
+                                item[index] = item[index] * dividend_cache["factor"]
+                csv_writer.writerow(item)
+                if isinstance(self._csv_file_name, asyncio.StreamWriter):
+                    await self._csv_file_name.drain()
         finally:
-            task.cancel()
-            await asyncio.gather(task, return_exceptions=True)
-
-    async def _timeout_handle(self, timeout, chart):
-        await asyncio.sleep(timeout)
-        if chart.get("left_id", -1) == -1 and chart.get("right_id", -1) == -1:
-            self._task.cancel()
+            if isinstance(self._csv_file_name, asyncio.StreamWriter):
+                self._csv_file_name.write_eof()
+            else:
+                writer.close()
+            # 这里 `await gen.aclose()` 实际测试代码与文档描述不符，无论文件全部下载完正常退出还是写文件过程中抛出例外退出，都没有再抛出任何例外
+            # https://docs.python.org/3/reference/expressions.html#agen.aclose
+            await gen.aclose()
 
     async def _download_data(self):
         """下载数据, 多合约横向按时间对齐"""
@@ -286,8 +279,6 @@ class DataDownloader:
         # 还没有发送过任何请求, 先请求定位左端点
         await self._api._send_chan.send(chart_info)
         chart = _get_obj(self._api._data, ["charts", chart_info["chart_id"]])
-        # 增加一个 task，在 30s 后检查 chart 是否返回了左右 id 范围，如果没有就 cancel self._task，防止程序一直卡在那里
-        timeout_task = self._api.create_task(self._timeout_handle(self._timeout_seconds, chart))
         current_id = None  # 当前数据指针
         data_cols = self._get_data_cols()
         serials = []
@@ -301,15 +292,12 @@ class DataDownloader:
                     if not (chart_info.items() <= _get_obj(chart, ["state"]).items()):
                         # 当前请求还没收齐回应, 不应继续处理
                         continue
+                    if chart.get("ready", False) is False:
+                        continue  # 数据序列还没收到，包含主合约和所有副合约
+                    if serials[0].get("last_id", -1) == -1:
+                        return  # 没有数据，直接退出
                     left_id = chart.get("left_id", -1)
                     right_id = chart.get("right_id", -1)
-                    if (left_id == -1 and right_id == -1) or self._api._data.get("mdhis_more_data", True):
-                        # 定位信息还没收到, 或数据序列还没收到
-                        continue
-                    for serial in serials:
-                        # 检查合约的数据是否收到
-                        if serial.get("last_id", -1) == -1:
-                            continue
                     if current_id is None:
                         current_id = max(left_id, 0)
                     while current_id <= right_id:
@@ -326,7 +314,7 @@ class DataDownloader:
                             k = {} if tid == -1 else serials[i]["data"].get(str(tid), {})
                             for col in data_cols:
                                 row.append(self._get_value(k, col, self._quote_list[i]["price_decs"]))
-                        await self._data_chan.send(row)
+                        yield row
                         current_id += 1
                         self._current_dt_nano = item["datetime"]
                     # 当前 id 已超出订阅范围, 需重新订阅后续数据
@@ -336,7 +324,6 @@ class DataDownloader:
                     await self._api._send_chan.send(chart_info)
         finally:
             # 释放chart资源
-            await self._data_chan.close()
             await self._api._send_chan.send({
                 "aid": "set_chart",
                 "chart_id": chart_info["chart_id"],
@@ -344,8 +331,6 @@ class DataDownloader:
                 "duration": self._dur_nano,
                 "view_width": 2000,
             })
-            timeout_task.cancel()
-            await timeout_task
 
     def _get_headers(self):
         data_cols = self._get_data_cols()
@@ -355,7 +340,7 @@ class DataDownloader:
         if self._dur_nano != 0:
             return ["open", "high", "low", "close", "volume", "open_oi", "close_oi"]
         else:
-            cols = ["last_price", "highest", "lowest", "volume", "amount", "open_interest"]
+            cols = ["last_price", "highest", "lowest", "average", "volume", "amount", "open_interest"]
             price_range = 1
             for symbol in self._symbol_list:
                 if symbol.split('.')[0] in {"SHFE", "INE", "SSE", "SZSE"}:
@@ -367,18 +352,18 @@ class DataDownloader:
 
     @staticmethod
     def _get_value(obj, key, price_decs):
-        if key not in obj:
+        try:
+            if key in PRICE_KEYS:
+                return round(obj[key], price_decs)
+            else:
+                return obj[key]
+        except KeyError:
             return "#N/A"
-        if isinstance(obj[key], str):
+        except TypeError:
             return float("nan")
-        if key in PRICE_KEYS:
-            return round(obj[key], price_decs)
-        else:
-            return obj[key]
 
     @staticmethod
     def _nano_to_str(nano):
-        dt = datetime.fromtimestamp(nano // 1000000000)
-        s = dt.strftime('%Y-%m-%d %H:%M:%S')
-        s += '.' + str(int(nano % 1000000000)).zfill(9)
-        return s
+        # 这里为了保留 nano 精度，没有用 datetime._timestamp_nano_to_str
+        dt = datetime.fromtimestamp(nano // 1000000000, tz=_cst_tz)
+        return "%d-%02d-%02d %02d:%02d:%02d.%09d" % (dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second, int(nano) % 1000000000)
