@@ -17,7 +17,7 @@ from tqsdk.tradeable.sim.basesim import BaseSim
 from tqsdk.auth import TqAuth
 from tqsdk.backtest import TqBacktest, TqReplay
 from tqsdk.channel import TqChan
-from tqsdk.datetime import _get_trading_day_start_time
+from tqsdk.datetime import _get_trading_day_start_time, _datetime_to_timestamp_nano
 from tqsdk.diff import _simple_merge_diff
 from tqsdk.tradeable import TqAccount, TqKq, TqSim
 
@@ -35,16 +35,16 @@ class TqWebHelper(object):
         if args["_action"] == "run":
             # 运行模式下，账户参数冲突需要抛错，提示用户
             if args["_broker_id"] == "TQ_KQ":
-                if type(self._api._account) is TqAccount:
-                    raise Exception("策略代码与插件设置中的账户参数冲突。可尝试删去代码中的账户参数 TqAccount，以插件设置的账户参数运行。")
+                if not isinstance(self._api._account, TqKq) and not isinstance(self._api._account, TqSim):
+                    raise Exception("策略代码与插件设置中的账户参数冲突。可尝试删去代码中的账户参数，以插件设置的账户参数运行。")
                 self._api._account = TqKq()
             elif args["_broker_id"] and args["_account_id"] and args["_password"]:
-                if isinstance(self._api._account, TqKq):
-                    raise Exception("策略代码与插件设置中的账户参数冲突。可尝试删去代码中的账户参数 TqKq，以插件设置的账户参数运行。")
-                if isinstance(self._api._account, TqAccount) and \
-                        (self._api._account._account_id != args["_account_id"] or self._api._account._broker_id !=
-                         args["_broker_id"]):
-                    raise Exception("策略代码与插件设置中的账户参数冲突。可尝试删去代码中的账户参数 TqAccount，以插件设置的账户参数运行。")
+                if isinstance(self._api._account, TqSim):
+                    pass
+                elif isinstance(self._api._account, TqAccount) and self._api._account._account_id == args["_account_id"] and self._api._account._broker_id == args["_broker_id"]:
+                    pass
+                else:
+                    raise Exception("策略代码与插件设置中的账户参数冲突。可尝试删去代码中的账户参数，以插件设置的账户参数运行。")
                 self._api._account = TqAccount(args["_broker_id"], args["_account_id"], args["_password"])
             else:
                 self._api._account = TqSim(args["_init_balance"])
@@ -82,14 +82,14 @@ class TqWebHelper(object):
                     if pack['aid'] not in ['set_chart_data', 'set_report_data']:
                         await web_send_chan.send(pack)
             finally:
-                _data_handler_without_web_task.cancel()
-                await asyncio.gather(_data_handler_without_web_task, return_exceptions=True)
+                await self._api._cancel_task(_data_handler_without_web_task)
         else:
             self._web_dir = os.path.join(os.path.dirname(__file__), 'web')
             file_path = os.path.abspath(sys.argv[0])
             file_name = os.path.basename(file_path)
             # 初始化数据截面
             accounts_info = {
+                #@todo: 避免针对账户类型的特殊处理, 统一按照通知的形式更新连接状态, 同时解决回测模式下没有行情连接状态的问题
                 acc._account_key: {"td_url_status": True if isinstance(acc, BaseSim) else '-'}
                 for acc in self._api._account._account_list
             }
@@ -158,9 +158,7 @@ class TqWebHelper(object):
                         # 发送的转发给上游
                         await web_send_chan.send(pack)
             finally:
-                _data_task.cancel()
-                _httpserver_task.cancel()
-                await asyncio.gather(_data_task, _httpserver_task, return_exceptions=True)
+                await self._api._cancel_tasks(*[_data_task, _httpserver_task])
 
     async def _data_handler_without_web(self, api_recv_chan, web_recv_chan):
         # 没有 web_gui, 接受全部数据转发给下游 api_recv_chan
@@ -180,11 +178,15 @@ class TqWebHelper(object):
                         _simple_merge_diff(self._data["trade"], trade)
                         web_diffs.append({"trade": trade})
                         # 账户是否有变化
-                        static_balance_changed = d.get("trade", {}).get(self._api._account._get_account_key(account=None), {}).\
-                            get("accounts", {}).get("CNY", {}).get('static_balance')
-                        trades_changed = d.get("trade", {}).get(self._api._account._get_account_key(account=None), {}).get("trades", {})
-                        orders_changed = d.get("trade", {}).get(self._api._account._get_account_key(account=None), {}).get("orders", {})
-                        if static_balance_changed is not None or trades_changed != {} or orders_changed != {}:
+                        # todo: 这里本来使用类似 is_changing 的做法，判断 diffs 中是否有 static_balance 字段；由于 _simple_merge_diff 去掉了默认参数 reduce_diff
+                        #  现在修改为手动比较 diffs 中的 static_balance 和 self._data 中的 static_balance 是否一样
+                        account_key = self._api._account._get_account_key(account=None)
+                        current_static_balance = self._data["trade"].get(account_key, {}).get("accounts", {}).get("CNY", {}).get('static_balance')
+                        diff_static_balance = d.get("trade", {}).get(account_key, {}).get("accounts", {}).get("CNY", {}).get('static_balance', None)
+                        static_balance_changed = diff_static_balance is not None and current_static_balance != diff_static_balance
+                        trades_changed = d.get("trade", {}).get(account_key, {}).get("trades", {})
+                        orders_changed = d.get("trade", {}).get(account_key, {}).get("orders", {})
+                        if static_balance_changed is True or trades_changed != {} or orders_changed != {}:
                             account_changed = True
                     # 处理 backtest replay
                     if d.get("_tqsdk_backtest") or d.get("_tqsdk_replay"):
@@ -232,7 +234,7 @@ class TqWebHelper(object):
     def send_to_conn_chan(self, chan, diffs):
         last_diff = chan.recv_latest({})
         for d in diffs:
-            _simple_merge_diff(last_diff, d, reduce_diff = False)
+            _simple_merge_diff(last_diff, d)
         if last_diff != {}:
             chan.send_nowait(last_diff)
 
@@ -249,7 +251,7 @@ class TqWebHelper(object):
             else:
                 return tqsim_current_timestamp
         else:
-            return int(datetime.now().timestamp() * 1e9)
+            return _datetime_to_timestamp_nano(datetime.now())
 
     def get_snapshot(self):
         account = self._data.get("trade", {}).get(self._api._account._get_account_key(account=None), {}).get("accounts", {}).get("CNY", {})
@@ -285,6 +287,7 @@ class TqWebHelper(object):
         except Exception as e:
             await conn_chan.close()
             self._conn_diff_chans.remove(conn_chan)
+        return ws
 
     async def link_httpserver(self):
         try:
@@ -294,7 +297,7 @@ class TqWebHelper(object):
             }
             # TODO：在复盘模式下发送 replay_dt 给 web 端，服务器改完后可以去掉
             if isinstance(self._api._backtest, TqReplay):
-                url_response["replay_dt"] = int(datetime.combine(self._api._backtest._replay_dt, datetime.min.time()).timestamp() * 1e9)
+                url_response["replay_dt"] = _datetime_to_timestamp_nano(datetime.combine(self._api._backtest._replay_dt, datetime.min.time()))
             app = web.Application()
             app.router.add_get(path='/url', handler=lambda request: TqWebHelper.httpserver_url_handler(url_response))
             app.router.add_get(path='/', handler=self.httpserver_index_handler)
