@@ -5,6 +5,6 @@ __author__ = 'mayanqiong'
 
 
 from tqsdk.tradeable.otg.base_otg import BaseOtg
-from tqsdk.tradeable.otg import TqAccount, TqKq, TqKqStock
+from tqsdk.tradeable.otg import TqAccount, TqZq, TqKq, TqKqStock, TqCtp, TqRohon, TqJees, TqYida, TqTradingUnit
 from tqsdk.tradeable.sim.basesim import BaseSim
 from tqsdk.tradeable.sim import TqSim, TqSimStock
