@@ -5,20 +5,20 @@ __author__ = 'mayanqiong'
 
 import asyncio
 import time
+import os
 from abc import abstractmethod
-from datetime import datetime
 from typing import Type, Union
 
 from tqsdk.channel import TqChan
 from tqsdk.datetime import _get_trading_day_from_timestamp, _get_trading_day_end_time, _get_trade_timestamp, \
-    _is_in_trading_time, _format_from_timestamp_nano
+    _is_in_trading_time, _timestamp_nano_to_str, _str_to_timestamp_nano
 from tqsdk.diff import _get_obj, _register_update_chan, _merge_diff
 from tqsdk.entity import Entity
 from tqsdk.objs import Quote
 from tqsdk.tradeable.tradeable import Tradeable
 from tqsdk.tradeable.sim.trade_future import SimTrade
 from tqsdk.tradeable.sim.trade_stock import SimTradeStock
-from tqsdk.utils import _query_for_quote
+from tqsdk.utils import _query_for_quote, _forward_chan_handler
 
 
 class BaseSim(Tradeable):
@@ -79,9 +79,8 @@ class BaseSim(Tradeable):
             await super(BaseSim, self)._run(api, api_send_chan, api_recv_chan, md_send_chan, md_recv_chan)
         finally:
             self._handle_stat_report()
-            for s in self._quote_tasks:
-                self._quote_tasks[s]["task"].cancel()
-            await asyncio.gather(*[self._quote_tasks[s]["task"] for s in self._quote_tasks], return_exceptions=True)
+            tasks = [self._quote_tasks[s]["task"] for s in self._quote_tasks]
+            await self._api._cancel_tasks(*tasks)
 
     async def _handle_recv_data(self, pack, chan):
         """
@@ -172,7 +171,8 @@ class BaseSim(Tradeable):
         if quote.get("price_tick") == quote.get("price_tick"):
             return quote.copy()
         if quote.get("price_tick") != quote.get("price_tick"):
-            await self._md_send_chan.send(_query_for_quote(symbol))
+            for query_pack in _query_for_quote(symbol, self._api._pre20_ins_info.keys()):
+                await self._md_send_chan.send(query_pack)
         async for _ in quote_chan:
             quote_chan.task_done()
             if quote.get("price_tick") == quote.get("price_tick"):
@@ -186,7 +186,8 @@ class BaseSim(Tradeable):
             return quote.copy()
         if quote.get("price_tick") != quote.get("price_tick"):
             # 对于没有合约信息的 quote，发送查询合约信息的请求
-            await self._md_send_chan.send(_query_for_quote(symbol))
+            for query_pack in _query_for_quote(symbol, self._api._pre20_ins_info.keys()):
+                await self._md_send_chan.send(query_pack)
         async for _ in quote_chan:
             quote_chan.task_done()
             if quote.get("datetime", "") and quote.get("price_tick") == quote.get("price_tick"):
@@ -219,7 +220,7 @@ class BaseSim(Tradeable):
             quote.update(self._data["quotes"][symbol])
             if underlying_quote:
                 underlying_quote.update(self._data["quotes"][underlying_symbol])
-            task = self._api.create_task(self._forward_chan_handler(order_chan, quote_chan))
+            task = self._api.create_task(_forward_chan_handler(order_chan, quote_chan))
             quotes = {symbol: quote}
             if underlying_quote:
                 quotes[underlying_symbol] = underlying_quote
@@ -238,12 +239,7 @@ class BaseSim(Tradeable):
         finally:
             await quote_chan.close()
             await order_chan.close()
-            task.cancel()
-            await asyncio.gather(task, return_exceptions=True)
-
-    async def _forward_chan_handler(self, chan_from, chan_to):
-        async for pack in chan_from:
-            await chan_to.send(pack)
+            await self._api._cancel_task(task)
 
     def _md_recv(self, pack):
         for d in pack["data"]:
@@ -263,8 +259,7 @@ class BaseSim(Tradeable):
             if _tqsdk_backtest:
                 # 回测时，用 _tqsdk_backtest 对象中 current_dt 作为 TqSim 的 _current_datetime
                 self._tqsdk_backtest.update(_tqsdk_backtest)
-                self._current_datetime = datetime.fromtimestamp(
-                    self._tqsdk_backtest["current_dt"] / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f")
+                self._current_datetime = _timestamp_nano_to_str(self._tqsdk_backtest["current_dt"])
                 self._local_time_record = float("nan")
                 # 1. 回测时不使用时间差来模拟交易所时间的原因(_local_time_record始终为初始值nan)：
                 #   在sim收到行情后记录_local_time_record，然后下发行情到api进行merge_diff(),api需要处理完k线和quote才能结束wait_update(),
@@ -289,15 +284,17 @@ class BaseSim(Tradeable):
                     # 导致前面处理 order 时的 _current_datetime 还是旧的行情时间
                     self._current_datetime = quote_diff["datetime"]  # 最新行情时间
                     # 更新最新行情时间时的本地时间，回测时不使用时间差
-                    self._local_time_record = (time.time() - 0.005) if not self._tqsdk_backtest else float("nan")
+                    # 在进行测试sim账号时(test_multi_account.py)也不使用时间差，因为会遇到和回测一样的问题:
+                    #   在sim收到行情后记录_local_time_record，然后下发行情到api进行merge_diff(),api需要处理完k线和quote才能结束wait_update(),
+                    #   若处理时间过长，此时下单则在判断下单时间时与测试用例中的预期时间相差较大，导致测试用例无法通过。
+                    self._local_time_record = float("nan") if self._tqsdk_backtest or "TQSDK_RUN_TEST" in os.environ else (time.time() - 0.005)
                 if self._current_datetime > self._trading_day_end:  # 结算
                     self._settle()
                     # 若当前行情时间大于交易日的结束时间(切换交易日)，则根据此行情时间更新交易日及交易日结束时间
                     trading_day = _get_trading_day_from_timestamp(self._get_current_timestamp())
-                    self._trading_day_end = datetime.fromtimestamp(
-                        (_get_trading_day_end_time(trading_day) - 999) / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f")
+                    self._trading_day_end = _timestamp_nano_to_str(_get_trading_day_end_time(trading_day) - 999)
             if quotes_diff:
-                _merge_diff(self._data, {"quotes": quotes_diff}, self._prototype, False, True)
+                _merge_diff(self._data, {"quotes": quotes_diff}, self._prototype, persist=False, reduce_diff=False, notify_update_diff=True)
 
     def _handle_diffs(self, diffs, orders_events, msg):
         """
@@ -339,7 +336,7 @@ class BaseSim(Tradeable):
         pass
 
     def _get_current_timestamp(self):
-        return int(datetime.strptime(self._current_datetime, "%Y-%m-%d %H:%M:%S.%f").timestamp() * 1e6) * 1000
+        return _str_to_timestamp_nano(self._current_datetime)
 
     def _get_trade_timestamp(self):
         return _get_trade_timestamp(self._current_datetime, self._local_time_record)
